@@ -1,23 +1,6 @@
-/* BSE - Better Sound Engine
- * Copyright (C) 2004 Tim Janik
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * A copy of the GNU Lesser General Public License should ship along
- * with this library; if not, see http://www.gnu.org/copyleft/.
- */
+// Licensed GNU LGPL v2.1 or later: http://www.gnu.org/licenses/lgpl.html
 #include "bsebusmodule.genidl.hh"
-
 namespace Bse {
-
 class BusModule : public BusModuleBase {
   /* bus-module module implementation */
   class Module : public SynthesisModule {
@@ -35,7 +18,7 @@ class BusModule : public BusModuleBase {
     {
     }
     void
-    process (unsigned int n_values)
+    process (uint n_values)
     {
       if (istream (ICHANNEL_AUDIO_IN1).connected && ostream (OCHANNEL_AUDIO_OUT1).connected)
         {
@@ -73,8 +56,6 @@ public:
   /* implement creation and config methods for synthesis Module */
   BSE_EFFECT_INTEGRATE_MODULE (BusModule, Module, BusModuleProperties);
 };
-
 BSE_CXX_DEFINE_EXPORTS ();
 BSE_CXX_REGISTER_EFFECT (BusModule);
-
 } // Bse
