@@ -1,24 +1,7 @@
-/* BSE - Better Sound Engine
- * Copyright (C) 2003 Tim Janik
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * A copy of the GNU Lesser General Public License should ship along
- * with this library; if not, see http://www.gnu.org/copyleft/.
- */
+// Licensed GNU LGPL v2.1 or later: http://www.gnu.org/licenses/lgpl.html
 #include "bsecxxvalue.hh"
 #include "bsecxxbase.hh"
-
 namespace Bse {
-
 SfiNum
 Value::get_num () const
 {
@@ -36,7 +19,6 @@ Value::get_num () const
   else
     throw WrongTypeGValue (G_STRLOC);
 }
-
 SfiReal
 Value::get_real () const
 {
@@ -50,8 +32,7 @@ Value::get_real () const
   else
     throw WrongTypeGValue (G_STRLOC);
 }
-
-const SfiString
+const char*
 Value::get_string () const
 {
   GValue *v = gvalue();
@@ -62,7 +43,6 @@ Value::get_string () const
   else
     throw WrongTypeGValue (G_STRLOC);
 }
-
 gpointer
 Value::get_pointer () const
 {
@@ -72,7 +52,6 @@ Value::get_pointer () const
   else
     throw WrongTypeGValue (G_STRLOC);
 }
-
 CxxBase*
 Value::get_base () const
 {
@@ -87,7 +66,6 @@ Value::get_base () const
   else
     throw WrongTypeGValue (G_STRLOC);
 }
-
 GObject*
 Value::get_object () const
 {
@@ -97,7 +75,6 @@ Value::get_object () const
   else
     throw WrongTypeGValue (G_STRLOC);
 }
-
 GParamSpec*
 Value::get_pspec () const
 {
@@ -107,7 +84,6 @@ Value::get_pspec () const
   else
     throw WrongTypeGValue (G_STRLOC);
 }
-
 void
 Value::set_num (SfiNum n)
 {
@@ -125,7 +101,6 @@ Value::set_num (SfiNum n)
   else
     throw WrongTypeGValue (G_STRLOC);
 }
-
 void
 Value::set_real (SfiReal r)
 {
@@ -139,7 +114,6 @@ Value::set_real (SfiReal r)
   else
     throw WrongTypeGValue (G_STRLOC);
 }
-
 void
 Value::set_string (const char      *s)
 {
@@ -151,7 +125,6 @@ Value::set_string (const char      *s)
   else
     throw WrongTypeGValue (G_STRLOC);
 }
-
 void
 Value::set_pointer (gpointer p)
 {
@@ -161,7 +134,6 @@ Value::set_pointer (gpointer p)
   else
     throw WrongTypeGValue (G_STRLOC);
 }
-
 void
 Value::set_base (CxxBase *b)
 {
@@ -176,7 +148,6 @@ Value::set_base (CxxBase *b)
   else
     throw WrongTypeGValue (G_STRLOC);
 }
-
 void
 Value::set_object (GObject *o)
 {
@@ -186,7 +157,6 @@ Value::set_object (GObject *o)
   else
     throw WrongTypeGValue (G_STRLOC);
 }
-
 void
 Value::set_pspec (GParamSpec *p)
 {
@@ -196,5 +166,4 @@ Value::set_pspec (GParamSpec *p)
   else
     throw WrongTypeGValue (G_STRLOC);
 }
-
 } // Bse
