@@ -2,25 +2,29 @@
 
 
 
-/* --- gsldatacache.h --- */
+/* --- gsldatacache.hh --- */
 #define BSE_TYPE_DATA_CACHE_REQUEST	    (BSE_TYPE_ID (GslDataCacheRequest))
 extern GType BSE_TYPE_ID (GslDataCacheRequest);
 
-/* --- gslvorbis-cutter.h --- */
+/* --- gslvorbis-cutter.hh --- */
 #define BSE_TYPE_VORBIS_CUTTER_MODE	    (BSE_TYPE_ID (GslVorbisCutterMode))
 extern GType BSE_TYPE_ID (GslVorbisCutterMode);
 
-/* --- bseexports.h --- */
+/* --- bseexports.hh --- */
 #define BSE_TYPE_EXPORT_NODE_TYPE	    (BSE_TYPE_ID (BseExportNodeType))
 extern GType BSE_TYPE_ID (BseExportNodeType);
 
-/* --- bsebiquadfilter.h --- */
+/* --- bsebiquadfilter.hh --- */
 #define BSE_TYPE_BIQUAD_FILTER_TYPE	    (BSE_TYPE_ID (BseBiquadFilterType))
 extern GType BSE_TYPE_ID (BseBiquadFilterType);
 #define BSE_TYPE_BIQUAD_FILTER_NORM	    (BSE_TYPE_ID (BseBiquadFilterNorm))
 extern GType BSE_TYPE_ID (BseBiquadFilterNorm);
 
-/* --- bseenums.h --- */
+/* --- bseenums.hh --- */
+#define BSE_TYPE_IIR_FILTER_ALGORITHM	    (BSE_TYPE_ID (BseIIRFilterAlgorithm))
+extern GType BSE_TYPE_ID (BseIIRFilterAlgorithm);
+#define BSE_TYPE_IIR_FILTER_TYPE	    (BSE_TYPE_ID (BseIIRFilterType))
+extern GType BSE_TYPE_ID (BseIIRFilterType);
 #define BSE_TYPE_REGISTRATION_TYPE	    (BSE_TYPE_ID (BseRegistrationType))
 extern GType BSE_TYPE_ID (BseRegistrationType);
 #define BSE_TYPE_INTERPOL_TYPE	    (BSE_TYPE_ID (BseInterpolType))
@@ -32,23 +36,23 @@ extern GType BSE_TYPE_ID (BseMagicFlags);
 #define BSE_TYPE_ERROR_TYPE	    (BSE_TYPE_ID (BseErrorType))
 extern GType BSE_TYPE_ID (BseErrorType);
 
-/* --- bseglobals.h --- */
+/* --- bseglobals.hh --- */
 #define BSE_TYPE_TIME_RANGE_TYPE	    (BSE_TYPE_ID (BseTimeRangeType))
 extern GType BSE_TYPE_ID (BseTimeRangeType);
 
-/* --- bsemidievent.h --- */
+/* --- bsemidievent.hh --- */
 #define BSE_TYPE_MIDI_EVENT_TYPE	    (BSE_TYPE_ID (BseMidiEventType))
 extern GType BSE_TYPE_ID (BseMidiEventType);
 
-/* --- bseproject.h --- */
+/* --- bseproject.hh --- */
 #define BSE_TYPE_PROJECT_STATE	    (BSE_TYPE_ID (BseProjectState))
 extern GType BSE_TYPE_ID (BseProjectState);
 
-/* --- bsestandardosc.h --- */
+/* --- bsestandardosc.hh --- */
 #define BSE_TYPE_STANDARD_OSC_WAVE_TYPE	    (BSE_TYPE_ID (BseStandardOscWaveType))
 extern GType BSE_TYPE_ID (BseStandardOscWaveType);
 
-/* --- bsemididecoder.h --- */
+/* --- bsemididecoder.hh --- */
 #define BSE_TYPE_MIDI_DECODER_STATE	    (BSE_TYPE_ID (BseMidiDecoderState))
 extern GType BSE_TYPE_ID (BseMidiDecoderState);
 
@@ -59,151 +63,151 @@ extern GType BSE_TYPE_ID (BseMidiDecoderState);
  * Generated data (by mktypes.pl --externs)
  */
 
-/* --- bsebus.c --- */
+/* --- bsebus.cc --- */
 extern GType bse_type_builtin_id_BseBus;
 
-/* --- bsebiquadfilter.c --- */
+/* --- bsebiquadfilter.cc --- */
 extern GType bse_type_builtin_id_BseBiquadFilter;
 
-/* --- bseconstant.c --- */
+/* --- bseconstant.cc --- */
 extern GType bse_type_builtin_id_BseConstant;
 
-/* --- bsecontainer.c --- */
+/* --- bsecontainer.cc --- */
 extern GType bse_type_builtin_id_BseContainer;
 
-/* --- bsecontextmerger.c --- */
+/* --- bsecontextmerger.cc --- */
 extern GType bse_type_builtin_id_BseContextMerger;
 
-/* --- bsedatapocket.c --- */
+/* --- bsedatapocket.cc --- */
 extern GType bse_type_builtin_id_BseDataPocket;
 
-/* --- bseeditablesample.c --- */
+/* --- bseeditablesample.cc --- */
 extern GType bse_type_builtin_id_BseEditableSample;
 
-/* --- bseitem.c --- */
+/* --- bseitem.cc --- */
 extern GType bse_type_builtin_id_BseItem;
 
-/* --- bsejanitor.c --- */
+/* --- bsejanitor.cc --- */
 extern GType bse_type_builtin_id_BseJanitor;
 
 /* --- bseladspa.cc --- */
 extern GType bse_type_builtin_id_BseLadspaPlugin;
 
-/* --- bsemidicontroller.c --- */
+/* --- bsemidicontroller.cc --- */
 extern GType bse_type_builtin_id_BseMidiController;
 
-/* --- bsemididevice.c --- */
+/* --- bsemididevice.cc --- */
 extern GType bse_type_builtin_id_BseMidiDevice;
 
-/* --- bsedevice.c --- */
+/* --- bsedevice.cc --- */
 extern GType bse_type_builtin_id_BseDevice;
 
-/* --- bsemididevice-null.c --- */
+/* --- bsemididevice-null.cc --- */
 extern GType bse_type_builtin_id_BseMidiDeviceNULL;
 
-/* --- bsemididevice-oss.c --- */
+/* --- bsemididevice-oss.cc --- */
 extern GType bse_type_builtin_id_BseMidiDeviceOSS;
 
-/* --- bsemidinotifier.c --- */
+/* --- bsemidinotifier.cc --- */
 extern GType bse_type_builtin_id_BseMidiNotifier;
 
-/* --- bsemidisynth.c --- */
+/* --- bsemidisynth.cc --- */
 extern GType bse_type_builtin_id_BseMidiSynth;
 
-/* --- bseobject.c --- */
+/* --- bseobject.cc --- */
 extern GType bse_type_builtin_id_BseObject;
 
-/* --- bsepart.c --- */
+/* --- bsepart.cc --- */
 extern GType bse_type_builtin_id_BsePart;
 
-/* --- bsepcminput.c --- */
+/* --- bsepcminput.cc --- */
 extern GType bse_type_builtin_id_BsePcmInput;
 
-/* --- bsepcmoutput.c --- */
+/* --- bsepcmoutput.cc --- */
 extern GType bse_type_builtin_id_BsePcmOutput;
 
-/* --- bsepcmdevice.c --- */
+/* --- bsepcmdevice.cc --- */
 extern GType bse_type_builtin_id_BsePcmDevice;
 
-/* --- bsepcmdevice-oss.c --- */
+/* --- bsepcmdevice-oss.cc --- */
 extern GType bse_type_builtin_id_BsePcmDeviceOSS;
 
-/* --- bsepcmdevice-null.c --- */
+/* --- bsepcmdevice-null.cc --- */
 extern GType bse_type_builtin_id_BsePcmDeviceNull;
 
-/* --- bseplugin.c --- */
+/* --- bseplugin.cc --- */
 extern GType bse_type_builtin_id_BsePlugin;
 
-/* --- bseproject.c --- */
+/* --- bseproject.cc --- */
 extern GType bse_type_builtin_id_BseProject;
 
-/* --- bseserver.c --- */
+/* --- bseserver.cc --- */
 extern GType bse_type_builtin_id_BseServer;
 
-/* --- bsesnet.c --- */
+/* --- bsesnet.cc --- */
 extern GType bse_type_builtin_id_BseSNet;
 
-/* --- bsesnooper.c --- */
+/* --- bsesnooper.cc --- */
 extern GType bse_type_builtin_id_BseSnooper;
 
-/* --- bsesong.c --- */
+/* --- bsesong.cc --- */
 extern GType bse_type_builtin_id_BseSong;
 
-/* --- bsesource.c --- */
+/* --- bsesource.cc --- */
 extern GType bse_type_builtin_id_BseSource;
 
-/* --- bsestandardosc.c --- */
+/* --- bsestandardosc.cc --- */
 extern GType bse_type_builtin_id_BseStandardOsc;
 
-/* --- bsestorage.c --- */
+/* --- bsestorage.cc --- */
 extern GType bse_type_builtin_id_BseStorage;
 
-/* --- bseinstrumentoutput.c --- */
+/* --- bseinstrumentoutput.cc --- */
 extern GType bse_type_builtin_id_BseInstrumentOutput;
 
-/* --- bsesubiport.c --- */
+/* --- bsesubiport.cc --- */
 extern GType bse_type_builtin_id_BseSubIPort;
 
-/* --- bseinstrumentinput.c --- */
+/* --- bseinstrumentinput.cc --- */
 extern GType bse_type_builtin_id_BseInstrumentInput;
 
-/* --- bsesuboport.c --- */
+/* --- bsesuboport.cc --- */
 extern GType bse_type_builtin_id_BseSubOPort;
 
-/* --- bsesubsynth.c --- */
+/* --- bsesubsynth.cc --- */
 extern GType bse_type_builtin_id_BseSubSynth;
 
-/* --- bsesuper.c --- */
+/* --- bsesuper.cc --- */
 extern GType bse_type_builtin_id_BseSuper;
 
-/* --- bsetrack.c --- */
+/* --- bsetrack.cc --- */
 extern GType bse_type_builtin_id_BseTrack;
 
-/* --- bsemidivoice.c --- */
+/* --- bsemidivoice.cc --- */
 extern GType bse_type_builtin_id_BseMidiVoiceInput;
 
-/* --- bsemidivoice.c --- */
+/* --- bsemidivoice.cc --- */
 extern GType bse_type_builtin_id_BseMidiVoiceSwitch;
 
-/* --- bsewave.c --- */
+/* --- bsewave.cc --- */
 extern GType bse_type_builtin_id_BseWave;
 
-/* --- bsewaveosc.c --- */
+/* --- bsewaveosc.cc --- */
 extern GType bse_type_builtin_id_BseWaveOsc;
 
-/* --- bsecsynth.c --- */
+/* --- bsecsynth.cc --- */
 extern GType bse_type_builtin_id_BseCSynth;
 
-/* --- bsewaverepo.c --- */
+/* --- bsewaverepo.cc --- */
 extern GType bse_type_builtin_id_BseWaveRepo;
 
-/* --- bseladspamodule.c --- */
+/* --- bseladspamodule.cc --- */
 extern GType bse_type_builtin_id_BseLadspaModule;
 
-/* --- bsepcmwriter.c --- */
+/* --- bsepcmwriter.cc --- */
 extern GType bse_type_builtin_id_BsePcmWriter;
 
-/* --- bsemidiinput.c --- */
+/* --- bsemidiinput.cc --- */
 extern GType bse_type_builtin_id_BseMidiInput;
 
 /*
@@ -644,10 +648,12 @@ typedef struct _BseGConfig BseGConfig;
 typedef struct _BseIntSeq BseIntSeq;
 typedef struct _BseTypeSeq BseTypeSeq;
 typedef struct _BseStringSeq BseStringSeq;
+typedef struct _BseFloatSeq BseFloatSeq;
 typedef struct _BseNoteSeq BseNoteSeq;
 typedef struct _BseItemSeq BseItemSeq;
 typedef struct _BsePartNoteSeq BsePartNoteSeq;
 typedef struct _BsePartControlSeq BsePartControlSeq;
+typedef struct _BsePixelSeq BsePixelSeq;
 typedef struct _BseCategorySeq BseCategorySeq;
 typedef struct _BseDotSeq BseDotSeq;
 typedef struct _BsePartLinkSeq BsePartLinkSeq;
@@ -668,6 +674,10 @@ struct _BseStringSeq {
   guint n_strings;
   gchar** strings;
 };
+struct _BseFloatSeq {
+  guint n_values;
+  SfiReal* values;
+};
 struct _BseNoteSeq {
   guint n_notes;
   SfiInt* notes;
@@ -684,6 +694,10 @@ struct _BsePartControlSeq {
   guint n_pcontrols;
   BsePartControl** pcontrols;
 };
+struct _BsePixelSeq {
+  guint n_pixels;
+  SfiInt* pixels;
+};
 struct _BseCategorySeq {
   guint n_cats;
   BseCategory** cats;
@@ -762,10 +776,9 @@ struct _BseNoteSequence {
   BseNoteSeq* notes;
 };
 struct _BseIcon {
-  SfiInt bytes_per_pixel;
   SfiInt width;
   SfiInt height;
-  SfiBBlock* pixels;
+  BsePixelSeq* pixel_seq;
 };
 struct _BseCategory {
   SfiInt category_id;
@@ -1003,6 +1016,15 @@ SfiSeq *bse_string_seq_to_seq (BseStringSeq* seq);
 void bse_string_seq_resize (BseStringSeq* seq, guint new_size);
 void bse_string_seq_free (BseStringSeq* seq);
 
+GParamSpec* bse_float_seq_get_element (void);
+BseFloatSeq* bse_float_seq_new (void);
+void bse_float_seq_append (BseFloatSeq* seq, SfiReal element);
+BseFloatSeq* bse_float_seq_copy_shallow (BseFloatSeq* seq);
+BseFloatSeq* bse_float_seq_from_seq (SfiSeq *sfi_seq);
+SfiSeq *bse_float_seq_to_seq (BseFloatSeq* seq);
+void bse_float_seq_resize (BseFloatSeq* seq, guint new_size);
+void bse_float_seq_free (BseFloatSeq* seq);
+
 GParamSpec* bse_note_seq_get_element (void);
 BseNoteSeq* bse_note_seq_new (void);
 void bse_note_seq_append (BseNoteSeq* seq, SfiInt element);
@@ -1039,6 +1061,15 @@ SfiSeq *bse_part_control_seq_to_seq (BsePartControlSeq* seq);
 void bse_part_control_seq_resize (BsePartControlSeq* seq, guint new_size);
 void bse_part_control_seq_free (BsePartControlSeq* seq);
 
+GParamSpec* bse_pixel_seq_get_element (void);
+BsePixelSeq* bse_pixel_seq_new (void);
+void bse_pixel_seq_append (BsePixelSeq* seq, SfiInt element);
+BsePixelSeq* bse_pixel_seq_copy_shallow (BsePixelSeq* seq);
+BsePixelSeq* bse_pixel_seq_from_seq (SfiSeq *sfi_seq);
+SfiSeq *bse_pixel_seq_to_seq (BsePixelSeq* seq);
+void bse_pixel_seq_resize (BsePixelSeq* seq, guint new_size);
+void bse_pixel_seq_free (BsePixelSeq* seq);
+
 GParamSpec* bse_category_seq_get_element (void);
 BseCategorySeq* bse_category_seq_new (void);
 void bse_category_seq_append (BseCategorySeq* seq, BseCategory* element);
@@ -1128,10 +1159,12 @@ extern GType bse__type_id__gconfig;
 extern GType bse__type_id__int_seq;
 extern GType bse__type_id__type_seq;
 extern GType bse__type_id__string_seq;
+extern GType bse__type_id__float_seq;
 extern GType bse__type_id__note_seq;
 extern GType bse__type_id__item_seq;
 extern GType bse__type_id__part_note_seq;
 extern GType bse__type_id__part_control_seq;
+extern GType bse__type_id__pixel_seq;
 extern GType bse__type_id__category_seq;
 extern GType bse__type_id__dot_seq;
 extern GType bse__type_id__part_link_seq;
@@ -1174,10 +1207,12 @@ extern GType bse__type_id__thread_info_seq;
 #define BSE_TYPE_INT_SEQ		(bse__type_id__int_seq)
 #define BSE_TYPE_TYPE_SEQ		(bse__type_id__type_seq)
 #define BSE_TYPE_STRING_SEQ		(bse__type_id__string_seq)
+#define BSE_TYPE_FLOAT_SEQ		(bse__type_id__float_seq)
 #define BSE_TYPE_NOTE_SEQ		(bse__type_id__note_seq)
 #define BSE_TYPE_ITEM_SEQ		(bse__type_id__item_seq)
 #define BSE_TYPE_PART_NOTE_SEQ		(bse__type_id__part_note_seq)
 #define BSE_TYPE_PART_CONTROL_SEQ		(bse__type_id__part_control_seq)
+#define BSE_TYPE_PIXEL_SEQ		(bse__type_id__pixel_seq)
 #define BSE_TYPE_CATEGORY_SEQ		(bse__type_id__category_seq)
 #define BSE_TYPE_DOT_SEQ		(bse__type_id__dot_seq)
 #define BSE_TYPE_PART_LINK_SEQ		(bse__type_id__part_link_seq)
