@@ -1,48 +1,27 @@
-/* BSE - Better Sound Engine
- * Copyright (C) 1996-1999, 2000-2004 Tim Janik
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * A copy of the GNU Lesser General Public License should ship along
- * with this library; if not, see http://www.gnu.org/copyleft/.
- */
-#include "bsemidireceiver.h"
-
-#include "bsemain.h"
-#include "gslcommon.h"
-#include "bseengine.h"
-#include "bsemathsignal.h"
+// Licensed GNU LGPL v2.1 or later: http://www.gnu.org/licenses/lgpl.html
+#include "bsemidireceiver.hh"
+#include "bsemain.hh"
+#include "gslcommon.hh"
+#include "bseengine.hh"
+#include "bsemathsignal.hh"
 #include "bsecxxutils.hh"
-#include "bsemidinotifier.h"
+#include "bsemidinotifier.hh"
 #include <string.h>
-#include <sfi/gbsearcharray.h>
+#include <sfi/gbsearcharray.hh>
 #include <map>
 #include <set>
-
 namespace {
 using namespace Bse;
 using namespace Birnet;
 using namespace std;
-
 static SFI_MSG_TYPE_DEFINE (debug_midi_receiver, "midi-receiver", SFI_MSG_DEBUG, NULL);
 #define DEBUG(...)              sfi_debug (debug_midi_receiver, __VA_ARGS__)
 static SFI_MSG_TYPE_DEFINE (debug_midi_events, "midi-events", SFI_MSG_DEBUG, NULL);
 #define DEBUG_EVENTS(...)       sfi_debug (debug_midi_events, __VA_ARGS__)
-
 /* --- variables --- */
 static BirnetMutex                         global_midi_mutex = { 0, };
 #define	BSE_MIDI_RECEIVER_LOCK()        GSL_SPIN_LOCK (&global_midi_mutex)
 #define	BSE_MIDI_RECEIVER_UNLOCK()      GSL_SPIN_UNLOCK (&global_midi_mutex)
-
-
 /********************************************************************************
  *
  * Busy/idle states of a voice input and correspondance with table entries:
@@ -83,8 +62,6 @@ static BirnetMutex                         global_midi_mutex = { 0, };
  * *only* disconnect upon Done=1. Thus a Done=const(0) mesh can block voices
  * forever.
  *******************************************************************************/
-
-
 /* --- midi controls --- */
 struct ControlKey {
   guint                  midi_channel;
@@ -230,14 +207,10 @@ struct ControlValue {
     g_return_if_fail (cmodules == NULL);
   }
 };
-
-
 /* --- voice prototypes --- */
 typedef struct VoiceSwitch          VoiceSwitch;
 typedef struct VoiceInput           VoiceInput;
 typedef std::map<float,VoiceInput*> VoiceInputTable;
-
-
 /* --- midi channel --- */
 struct MidiChannel {
   guint           midi_channel;
@@ -298,8 +271,6 @@ midi_channel_compare (const guint        midi_channel,
 {
   return midi_channel < c2->midi_channel ? -1 : midi_channel > c2->midi_channel;
 }
-
-
 /* --- midi receiver --- */
 struct MidiReceiver
 {
@@ -445,8 +416,6 @@ public:
     cv->remove_handler (handler_func, handler_data, module);
   }
 };
-
-
 /* --- MIDI Control Module --- */
 typedef struct
 {
@@ -455,19 +424,16 @@ typedef struct
   BseMidiSignalType signals[BSE_MIDI_CONTROL_MODULE_N_CHANNELS];
   guint             ref_count;
 } MidiCModuleData;
-
 static void
 midi_control_module_process_U (BseModule *module, /* vswitch->smodule */
                                guint      n_values)
 {
   MidiCModuleData *cdata = (MidiCModuleData *) module->user_data;
   guint i;
-  
   for (i = 0; i < BSE_MODULE_N_OSTREAMS (module); i++)
     if (module->ostreams[i].connected)
       module->ostreams[i].values = bse_engine_const_values (cdata->values[i]);
 }
-
 static BseModule*
 create_midi_control_module_L (MidiReceiver      *self,
                               guint              midi_channel,
@@ -486,9 +452,7 @@ create_midi_control_module_L (MidiReceiver      *self,
   MidiCModuleData *cdata;
   BseModule *module;
   guint i;
-  
   g_return_val_if_fail (signals != NULL, NULL);
-  
   cdata = g_new0 (MidiCModuleData, 1);
   cdata->midi_channel = midi_channel;
   for (i = 0; i < BSE_MIDI_CONTROL_MODULE_N_CHANNELS; i++)
@@ -498,15 +462,12 @@ create_midi_control_module_L (MidiReceiver      *self,
     }
   cdata->ref_count = 1;
   module = bse_module_new (&midi_cmodule_class, cdata);
-  
   return module;
 }
-
 typedef struct {
   BseMidiSignalType signal;
   gfloat            value;
 } MidiCModuleAccessData;
-
 static void
 midi_control_module_access_U (BseModule *module,
                               gpointer   data)
@@ -514,12 +475,10 @@ midi_control_module_access_U (BseModule *module,
   MidiCModuleData *cdata = (MidiCModuleData *) module->user_data;
   MidiCModuleAccessData *adata = (MidiCModuleAccessData *) data;
   guint i;
-  
   for (i = 0; i < BSE_MIDI_CONTROL_MODULE_N_CHANNELS; i++)
     if (cdata->signals[i] == adata->signal)
       cdata->values[i] = adata->value;
 }
-
 static void
 change_midi_control_modules_L (GSList           *modules,
                                guint64           tick_stamp,
@@ -529,7 +488,6 @@ change_midi_control_modules_L (GSList           *modules,
 {
   MidiCModuleAccessData *adata;
   GSList *slist = modules;
-  
   if (!modules)
     return;
   adata = g_new0 (MidiCModuleAccessData, 1);
@@ -542,7 +500,6 @@ change_midi_control_modules_L (GSList           *modules,
 					       adata,
 					       slist->next ? NULL : g_free));
 }
-
 static gboolean
 match_midi_control_module_L (BseModule         *cmodule,
                              guint              midi_channel,
@@ -551,15 +508,11 @@ match_midi_control_module_L (BseModule         *cmodule,
   MidiCModuleData *cdata = (MidiCModuleData *) cmodule->user_data;
   gboolean match = TRUE;
   guint i;
-  
   for (i = 0; i < BSE_MIDI_CONTROL_MODULE_N_CHANNELS; i++)
     match &= cdata->signals[i] == signals[i];
   match &= cdata->midi_channel == midi_channel;
-  
   return match;
 }
-
-
 /* --- VoiceInput module --- */
 typedef enum {
   VOICE_ON = 1,
@@ -583,7 +536,6 @@ voice_change_to_string (VoiceChangeType t)
     }
   return "<invalid>";
 }
-
 typedef enum {
   VSTATE_IDLE,
   VSTATE_BUSY,      /* got note-on, waiting for note-off */
@@ -600,7 +552,6 @@ voice_state_to_string (VoiceState s)
     }
   return "<invalid>";
 }
-
 struct VoiceInput
 {
   /* module state */
@@ -618,13 +569,11 @@ struct VoiceInput
   VoiceInput      *next;
   VoiceInputTable::iterator iter;
 };
-
 static void
 voice_input_module_process_U (BseModule *module,
                               guint      n_values)
 {
   VoiceInput *vinput = (VoiceInput*) module->user_data;
-  
   if (BSE_MODULE_OSTREAM (module, 0).connected)
     BSE_MODULE_OSTREAM (module, 0).values = bse_engine_const_values (vinput->freq_value);
   if (BSE_MODULE_OSTREAM (module, 1).connected)
@@ -634,13 +583,11 @@ voice_input_module_process_U (BseModule *module,
   if (BSE_MODULE_OSTREAM (module, 3).connected)
     BSE_MODULE_OSTREAM (module, 3).values = bse_engine_const_values (vinput->aftertouch);
 }
-
 typedef struct {
   VoiceChangeType vtype;
   gfloat          freq_value;
   gfloat          velocity;
 } VoiceInputData;
-
 static void
 voice_input_module_reset_U (BseModule *module)
 {
@@ -650,7 +597,6 @@ voice_input_module_reset_U (BseModule *module)
   vinput->velocity = 0.5;
   vinput->aftertouch = 0.5;
 }
-
 static void
 voice_input_remove_from_table_L (VoiceInput *vinput)    /* UserThread */
 {
@@ -673,7 +619,6 @@ voice_input_remove_from_table_L (VoiceInput *vinput)    /* UserThread */
       g_assert_not_reached ();
     }
 }
-
 static void
 voice_input_enter_sustain_U (gpointer data)     /* UserThread */
 {
@@ -683,7 +628,6 @@ voice_input_enter_sustain_U (gpointer data)     /* UserThread */
   vinput->queue_state = VSTATE_SUSTAINED;
   BSE_MIDI_RECEIVER_UNLOCK ();
 }
-
 static void
 voice_input_enter_idle_U (gpointer data)        /* UserThread */
 {
@@ -693,14 +637,12 @@ voice_input_enter_idle_U (gpointer data)        /* UserThread */
   vinput->queue_state = VSTATE_IDLE;
   BSE_MIDI_RECEIVER_UNLOCK ();
 }
-
 static void
 voice_input_module_access_U (BseModule *module,
                              gpointer   data)
 {
   VoiceInput *vinput = (VoiceInput*) module->user_data;
   VoiceInputData *mdata = (VoiceInputData *) data;
-  
   DEBUG ("Synth<%p:%08llx>: ProcessEvent=%s Freq=%.2fHz",
          vinput, bse_module_tick_stamp (module),
          voice_change_to_string (mdata->vtype),
@@ -746,7 +688,6 @@ voice_input_module_access_U (BseModule *module,
       break;
     }
 }
-
 static void
 change_voice_input_L (VoiceInput      *vinput,
                       guint64          tick_stamp,
@@ -799,13 +740,11 @@ change_voice_input_L (VoiceInput      *vinput,
   mdata.velocity = velocity;
   bse_trans_add (trans, bse_job_flow_access (vinput->fmodule, tick_stamp, voice_input_module_access_U, g_memdup (&mdata, sizeof (mdata)), g_free));
   vinput->tick_stamp = tick_stamp;
-
   DEBUG ("Synth<%p:%08llx>: QueueEvent=%s Freq=%.2fHz",
          vinput, tick_stamp,
          voice_change_to_string (vtype),
          BSE_FREQ_FROM_VALUE (freq_value));
 }
-
 static void
 voice_input_module_free_U (gpointer        data,
                            const BseModuleClass *klass)
@@ -814,7 +753,6 @@ voice_input_module_free_U (gpointer        data,
   g_assert (vinput->next == NULL);
   delete vinput;
 }
-
 static VoiceInput*
 create_voice_input_L (VoiceInputTable *table,
                       gboolean         ismono,
@@ -831,7 +769,6 @@ create_voice_input_L (VoiceInputTable *table,
     BSE_COST_CHEAP
   };
   VoiceInput *vinput = new VoiceInput;
-  
   vinput->fmodule = bse_module_new (&mono_synth_module_class, vinput);
   vinput->freq_value = 0;
   vinput->gate = 0;
@@ -845,22 +782,17 @@ create_voice_input_L (VoiceInputTable *table,
   vinput->next = NULL;
   vinput->iter = table->end();
   bse_trans_add (trans, bse_job_integrate (vinput->fmodule));
-  
   return vinput;
 }
-
 static void
 destroy_voice_input_L (VoiceInput      *vinput,
                        BseTrans        *trans)
 {
   g_return_if_fail (vinput->ref_count == 0);
-  
   if (vinput->table && vinput->iter != vinput->table->end())
     voice_input_remove_from_table_L (vinput);
   bse_trans_add (trans, bse_job_boundary_discard (vinput->fmodule));
 }
-
-
 /* --- VoiceSwitch module --- */
 struct VoiceSwitch
 {
@@ -873,7 +805,6 @@ struct VoiceSwitch
   BseModule        *smodule;            /* input module (switches and suspends) */
   BseModule        *vmodule;            /* output module (virtual) */
 };
-
 static void
 voice_switch_module_reuse_U (gpointer data)     /* UserThread */
 {
@@ -882,19 +813,16 @@ voice_switch_module_reuse_U (gpointer data)     /* UserThread */
   vswitch->disconnected = TRUE;         /* reuse possible */
   BSE_MIDI_RECEIVER_UNLOCK ();
 }
-
 static void
 voice_switch_module_process_U (BseModule *module,
                                guint      n_values)
 {
   VoiceSwitch *vswitch = (VoiceSwitch*) module->user_data;
   guint i;
-  
   /* dumb pass-through task */
   for (i = 0; i < BSE_MODULE_N_OSTREAMS (module); i++)
     if (BSE_MODULE_OSTREAM (module, i).connected)
       BSE_MODULE_OSTREAM (module, i).values = (gfloat*) BSE_MODULE_IBUFFER (module, i);
-  
   /* check Done state on last stream */
   if (BSE_MODULE_IBUFFER (module, BSE_MODULE_N_ISTREAMS (module) - 1)[n_values - 1] >= 1.0)
     {
@@ -912,7 +840,6 @@ voice_switch_module_process_U (BseModule *module,
       bse_engine_add_user_callback (vswitch, voice_switch_module_reuse_U);
     }
 }
-
 static void
 voice_switch_module_boundary_check_U (BseModule *module,
                                       gpointer   data)
@@ -929,7 +856,6 @@ voice_switch_module_boundary_check_U (BseModule *module,
       vswitch->disconnected = FALSE;      /* reset hint */
     }
 }
-
 static void
 activate_voice_switch_L (VoiceSwitch *vswitch,
                          guint64      tick_stamp,
@@ -942,7 +868,6 @@ activate_voice_switch_L (VoiceSwitch *vswitch,
   bse_trans_add (trans, bse_job_resume_at (vswitch->smodule, tick_stamp));
   vswitch->disconnected = FALSE;        /* reset hint ahead of time */
 }
-
 static void
 voice_switch_module_free_U (gpointer        data,
                             const BseModuleClass *klass)
@@ -951,7 +876,6 @@ voice_switch_module_free_U (gpointer        data,
   g_free (vswitch->vinputs);
   g_free (vswitch);
 }
-
 static VoiceSwitch*
 create_voice_switch_module_L (BseTrans *trans)
 {
@@ -966,7 +890,6 @@ create_voice_switch_module_L (BseTrans *trans)
     BSE_COST_CHEAP
   };
   VoiceSwitch *vswitch = g_new0 (VoiceSwitch, 1);
-  
   vswitch->disconnected = TRUE;
   vswitch->ref_count = 1;
   vswitch->smodule = bse_module_new (&switch_module_class, vswitch);
@@ -974,16 +897,13 @@ create_voice_switch_module_L (BseTrans *trans)
   bse_trans_add (trans, bse_job_integrate (vswitch->smodule));
   bse_trans_add (trans, bse_job_integrate (vswitch->vmodule));
   bse_trans_add (trans, bse_job_suspend_now (vswitch->smodule));
-  
   return vswitch;
 }
-
 static inline gboolean
 check_voice_switch_available_L (VoiceSwitch *vswitch)
 {
   return vswitch->disconnected;
 }
-
 static void
 voice_switch_module_commit_accessor_U (BseModule *module,
                                        gpointer   data)
@@ -991,16 +911,13 @@ voice_switch_module_commit_accessor_U (BseModule *module,
   BseTrans *trans = (BseTrans*) data;
   bse_trans_commit (trans);
 }
-
 static void
 destroy_voice_switch_L (VoiceSwitch *vswitch,
                         BseTrans     *trans)
 {
   BseTrans *tmp_trans;
-  
   g_return_if_fail (vswitch->ref_count == 0);
   g_return_if_fail (vswitch->n_vinputs == 0);
-  
   tmp_trans = bse_trans_open ();
   bse_trans_add (tmp_trans, bse_job_boundary_discard (vswitch->smodule));
   bse_trans_add (tmp_trans, bse_job_boundary_discard (vswitch->vmodule));
@@ -1012,8 +929,6 @@ destroy_voice_switch_L (VoiceSwitch *vswitch,
    */
   bse_trans_add (trans, bse_job_access (vswitch->smodule, voice_switch_module_commit_accessor_U, tmp_trans, NULL));
 }
-
-
 /* --- MidiChannel --- */
 static inline gboolean
 check_voice_input_improvement_L (VoiceInput *vinput1, /* vinput1 better than vinput2? */
@@ -1027,7 +942,6 @@ check_voice_input_improvement_L (VoiceInput *vinput1, /* vinput1 better than vin
     return vinput2->queue_state == VSTATE_IDLE ? FALSE : TRUE;
   return FALSE; /* vinput1->queue_state == VSTATE_BUSY && vinput1->queue_state != vinput2->queue_state */
 }
-
 void
 MidiChannel::no_poly_voice (const gchar *event_name,
                             gfloat       freq)
@@ -1042,7 +956,6 @@ MidiChannel::no_poly_voice (const gchar *event_name,
   sfi_diag ("MidiChannel(%u): no voice available for %s (%fHz)",
             mchannel->midi_channel, event_name, freq);
 }
-
 void
 MidiChannel::start_note (guint64         tick_stamp,
                          gfloat          freq,
@@ -1053,16 +966,12 @@ MidiChannel::start_note (guint64         tick_stamp,
   gfloat freq_val = BSE_VALUE_FROM_FREQ (freq);
   VoiceSwitch *vswitch, *override_candidate = NULL;
   guint i;
-  
   g_return_if_fail (freq > 0);
-  
   /* adjust channel global mono synth */
   if (mchannel->vinput)
     change_voice_input_L (mchannel->vinput, tick_stamp, VOICE_ON, freq_val, velocity, trans);
-
   if (!mchannel->poly_enabled)
     return;
-
   /* figure voice from event */
   vswitch = NULL; // voice numbers on events not currently supported
   /* find free poly voice */
@@ -1080,7 +989,6 @@ MidiChannel::start_note (guint64         tick_stamp,
   /* grab voice to override */
   if (!vswitch)
     ; // FIXME: voice = override_candidate;
-  
   if (vswitch && vswitch->n_vinputs)
     {
       /* start note */
@@ -1096,7 +1004,6 @@ MidiChannel::start_note (guint64         tick_stamp,
   else
     no_poly_voice ("note-on", freq);
 }
-
 void
 MidiChannel::adjust_note (guint64         tick_stamp,
                           gfloat           freq,
@@ -1109,28 +1016,22 @@ MidiChannel::adjust_note (guint64         tick_stamp,
   VoiceChangeType vctype = etype == BSE_MIDI_KEY_PRESSURE ? VOICE_PRESSURE : (sustain_note ? VOICE_SUSTAIN : VOICE_OFF);
   gfloat freq_val = BSE_VALUE_FROM_FREQ (freq);
   VoiceInput *vinput = NULL;
-  
   g_return_if_fail (freq > 0 && velocity >= 0);
-  
   /* adjust channel global mono synth */
   if (mchannel->vinput)
     change_voice_input_L (mchannel->vinput, tick_stamp, vctype, freq_val, velocity, trans);
-  
   if (!mchannel->poly_enabled)
     return;
-
   /* find corresponding vinput */
   vinput = mchannel->voice_input_table[freq_val];
   while (vinput && vinput->queue_state != VSTATE_BUSY)
     vinput = vinput->next;
-
   /* adjust note */
   if (vinput)
     change_voice_input_L (vinput, tick_stamp, vctype, freq_val, velocity, trans);
   else
     no_poly_voice (etype == BSE_MIDI_NOTE_OFF ? "note-off" : "velocity", freq);
 }
-
 void
 MidiChannel::kill_notes (guint64       tick_stamp,
                          gboolean      sustained_only,
@@ -1138,13 +1039,11 @@ MidiChannel::kill_notes (guint64       tick_stamp,
 {
   MidiChannel *mchannel = this;
   guint i, j;
-  
   /* adjust channel global voice inputs */
   if (mchannel->vinput && sustained_only && mchannel->vinput->queue_state == VSTATE_SUSTAINED)
     change_voice_input_L (mchannel->vinput, tick_stamp, VOICE_KILL_SUSTAIN, 0, 0, trans);
   else if (mchannel->vinput && !sustained_only && mchannel->vinput->queue_state != VSTATE_IDLE)
     change_voice_input_L (mchannel->vinput, tick_stamp, VOICE_KILL, 0, 0, trans);
-  
   /* adjust poly voice inputs */
   for (i = 0; i < mchannel->n_voices; i++)
     {
@@ -1157,7 +1056,6 @@ MidiChannel::kill_notes (guint64       tick_stamp,
             change_voice_input_L (vswitch->vinputs[j], tick_stamp, VOICE_KILL, 0, 0, trans);
     }
 }
-
 void
 MidiChannel::debug_notes (guint64          tick_stamp,
                           BseTrans        *trans)
@@ -1177,39 +1075,26 @@ MidiChannel::debug_notes (guint64          tick_stamp,
                     BSE_FREQ_FROM_VALUE (vswitch->vinputs[j]->freq_value));
     }
 }
-
 } // namespace anon
-
-
 /* --- BseMidiReceiver C API --- */
 extern "C" {
-
 struct _BseMidiReceiver : public MidiReceiver {
   explicit _BseMidiReceiver () :
     MidiReceiver () {}
 };
-
-
 /* --- prototypes --- */
 static gint	midi_receiver_process_event_L  (BseMidiReceiver        *self,
 						guint64                 max_tick_stamp);
-
-
 /* --- variables --- */
 static vector<BseMidiReceiver*> farm_residents;
-
-
 /* --- function --- */
 void
 _bse_midi_init (void)
 {
   static gboolean initialized = FALSE;
-  
   g_assert (initialized++ == FALSE);
-  
   sfi_mutex_init (&global_midi_mutex);
 }
-
 static gint
 events_cmp (gconstpointer a,
             gconstpointer b,
@@ -1217,32 +1102,26 @@ events_cmp (gconstpointer a,
 {
   const BseMidiEvent *e1 = (const BseMidiEvent *) a;
   const BseMidiEvent *e2 = (const BseMidiEvent *) b;
-  
   return e1->delta_time < e2->delta_time ? -1 : e1->delta_time != e2->delta_time;
 }
-
 void
 bse_midi_receiver_enter_farm (BseMidiReceiver *self)
 {
   g_return_if_fail (self != NULL);
   g_return_if_fail (find (farm_residents.begin(), farm_residents.end(), self) == farm_residents.end());
-  
   BSE_MIDI_RECEIVER_LOCK ();
   farm_residents.push_back (self);
   BSE_MIDI_RECEIVER_UNLOCK ();
 }
-
 void
 bse_midi_receiver_farm_distribute_event (BseMidiEvent *event)
 {
   g_return_if_fail (event != NULL);
-  
   BSE_MIDI_RECEIVER_LOCK ();
   for (vector<BseMidiReceiver*>::iterator it = farm_residents.begin(); it != farm_residents.end(); it++)
     (*it)->events = sfi_ring_insert_sorted ((*it)->events, bse_midi_copy_event (event), events_cmp, NULL);
   BSE_MIDI_RECEIVER_UNLOCK ();
 }
-
 void
 bse_midi_receiver_farm_process_events (guint64 max_tick_stamp)
 {
@@ -1257,38 +1136,31 @@ bse_midi_receiver_farm_process_events (guint64 max_tick_stamp)
     }
   while (seen_event);
 }
-
 void
 bse_midi_receiver_leave_farm (BseMidiReceiver *self)
 {
   g_return_if_fail (self != NULL);
   g_return_if_fail (find (farm_residents.begin(), farm_residents.end(), self) != farm_residents.end());
-  
   BSE_MIDI_RECEIVER_LOCK ();
   farm_residents.erase (find (farm_residents.begin(), farm_residents.end(), self));
   BSE_MIDI_RECEIVER_UNLOCK ();
 }
-
 void
 bse_midi_receiver_push_event (BseMidiReceiver *self,
 			      BseMidiEvent    *event)
 {
   g_return_if_fail (self != NULL);
   g_return_if_fail (event != NULL);
-  
   BSE_MIDI_RECEIVER_LOCK ();
   self->events = sfi_ring_insert_sorted (self->events, event, events_cmp, NULL);
   BSE_MIDI_RECEIVER_UNLOCK ();
 }
-
 void
 bse_midi_receiver_process_events (BseMidiReceiver *self,
 				  guint64          max_tick_stamp)
 {
   gboolean seen_event;
-  
   g_return_if_fail (self != NULL);
-  
   do
     {
       BSE_MIDI_RECEIVER_LOCK ();
@@ -1297,46 +1169,35 @@ bse_midi_receiver_process_events (BseMidiReceiver *self,
     }
   while (seen_event);
 }
-
-
 BseMidiReceiver*
 bse_midi_receiver_new (const gchar *receiver_name)  // FIXME
 {
   BseMidiReceiver *self;
-  
   self = new BseMidiReceiver ();
-  
   return self;
 }
-
 BseMidiReceiver*
 bse_midi_receiver_ref (BseMidiReceiver *self)
 {
   g_return_val_if_fail (self != NULL, NULL);
   g_return_val_if_fail (self->ref_count > 0, NULL);
-  
   BSE_MIDI_RECEIVER_LOCK ();
   self->ref_count++;
   BSE_MIDI_RECEIVER_UNLOCK ();
-  
   return self;
 }
-
 void
 bse_midi_receiver_unref (BseMidiReceiver *self)
 {
   gboolean need_destroy, leave_farm;
-  
   g_return_if_fail (self != NULL);
   g_return_if_fail (self->ref_count > 0);
-  
   BSE_MIDI_RECEIVER_LOCK ();
   self->ref_count--;
   need_destroy = self->ref_count == 0;
   leave_farm = need_destroy && find (farm_residents.begin(),
                                      farm_residents.end(), self) != farm_residents.end();
   BSE_MIDI_RECEIVER_UNLOCK ();
-  
   if (need_destroy)
     {
       if (leave_farm)
@@ -1344,15 +1205,12 @@ bse_midi_receiver_unref (BseMidiReceiver *self)
       delete self;
     }
 }
-
 void
 bse_midi_receiver_set_notifier (BseMidiReceiver *self,
 				BseMidiNotifier *notifier)
 {
   BseMidiNotifier *old_notifier;
-  
   g_return_if_fail (self != NULL);
-  
   BSE_MIDI_RECEIVER_LOCK ();
   old_notifier = self->notifier;
   self->notifier = notifier;
@@ -1368,29 +1226,23 @@ bse_midi_receiver_set_notifier (BseMidiReceiver *self,
       }
   BSE_MIDI_RECEIVER_UNLOCK ();
 }
-
 gboolean
 bse_midi_receiver_has_notify_events (BseMidiReceiver *self)
 {
   /* prolly don't need a lock */
   return self->notifier && self->notifier_events;
 }
-
 SfiRing*
 bse_midi_receiver_fetch_notify_events (BseMidiReceiver *self)
 {
   SfiRing *ring;
-  
   g_return_val_if_fail (self != NULL, NULL);
-  
   BSE_MIDI_RECEIVER_LOCK ();
   ring = self->notifier_events;
   self->notifier_events = NULL;
   BSE_MIDI_RECEIVER_UNLOCK ();
-  
   return ring;
 }
-
 BseModule*
 bse_midi_receiver_retrieve_control_module (BseMidiReceiver  *self,
 					   guint             midi_channel,
@@ -1399,11 +1251,9 @@ bse_midi_receiver_retrieve_control_module (BseMidiReceiver  *self,
 {
   BseModule *cmodule;
   guint i;
-  
   g_return_val_if_fail (self != NULL, NULL);
   g_return_val_if_fail (midi_channel > 0, NULL);
   g_return_val_if_fail (signals != NULL, NULL);
-  
   BSE_MIDI_RECEIVER_LOCK ();
   for (i = 0; i < self->n_cmodules; i++)
     {
@@ -1431,17 +1281,14 @@ bse_midi_receiver_retrieve_control_module (BseMidiReceiver  *self,
   BSE_MIDI_RECEIVER_UNLOCK ();
   return cmodule;
 }
-
 void
 bse_midi_receiver_discard_control_module (BseMidiReceiver *self,
                                           BseModule       *module,
 					  BseTrans        *trans)
 {
   guint i;
-  
   g_return_if_fail (self != NULL);
   g_return_if_fail (module != NULL);
-  
   BSE_MIDI_RECEIVER_LOCK ();
   for (i = 0; i < self->n_cmodules; i++)
     {
@@ -1473,7 +1320,6 @@ bse_midi_receiver_discard_control_module (BseMidiReceiver *self,
   BSE_MIDI_RECEIVER_UNLOCK ();
   g_warning ("no such control module: %p", module);
 }
-
 gboolean
 bse_midi_receiver_add_control_handler (BseMidiReceiver      *self,
                                        guint                 midi_channel,
@@ -1486,13 +1332,11 @@ bse_midi_receiver_add_control_handler (BseMidiReceiver      *self,
   g_return_val_if_fail (midi_channel > 0, FALSE);
   g_return_val_if_fail (handler_func != NULL, FALSE);
   g_return_val_if_fail (module != NULL, FALSE);
-  
   BSE_MIDI_RECEIVER_LOCK ();
   gboolean has_data = self->add_control_handler (midi_channel, signal_type, handler_func, handler_data, module);
   BSE_MIDI_RECEIVER_UNLOCK ();
   return has_data;
 }
-
 void
 bse_midi_receiver_set_control_handler_data (BseMidiReceiver      *self,
                                             guint                 midi_channel,
@@ -1505,12 +1349,10 @@ bse_midi_receiver_set_control_handler_data (BseMidiReceiver      *self,
   g_return_if_fail (self != NULL);
   g_return_if_fail (midi_channel > 0);
   g_return_if_fail (handler_func != NULL);
-  
   BSE_MIDI_RECEIVER_LOCK ();
   self->set_control_handler_data (midi_channel, signal_type, handler_func, handler_data, extra_data, extra_free);
   BSE_MIDI_RECEIVER_UNLOCK ();
 }
-
 void
 bse_midi_receiver_remove_control_handler (BseMidiReceiver      *self,
                                           guint                 midi_channel,
@@ -1523,48 +1365,40 @@ bse_midi_receiver_remove_control_handler (BseMidiReceiver      *self,
   g_return_if_fail (midi_channel > 0);
   g_return_if_fail (handler_func != NULL);
   g_return_if_fail (module != NULL);
-  
   BSE_MIDI_RECEIVER_LOCK ();
   self->remove_control_handler (midi_channel, signal_type, handler_func, handler_data, module);
   BSE_MIDI_RECEIVER_UNLOCK ();
 }
-
 void
 bse_midi_receiver_channel_enable_poly (BseMidiReceiver *self,
                                        guint            midi_channel)
 {
   g_return_if_fail (self != NULL);
   g_return_if_fail (midi_channel > 0);
-  
   BSE_MIDI_RECEIVER_LOCK ();
   MidiChannel *mchannel = self->get_channel (midi_channel);
   mchannel->enable_poly();
   BSE_MIDI_RECEIVER_UNLOCK ();
 }
-
 void
 bse_midi_receiver_channel_disable_poly (BseMidiReceiver *self,
                                         guint            midi_channel)
 {
   g_return_if_fail (self != NULL);
   g_return_if_fail (midi_channel > 0);
-  
   BSE_MIDI_RECEIVER_LOCK ();
   MidiChannel *mchannel = self->get_channel (midi_channel);
   mchannel->disable_poly();
   BSE_MIDI_RECEIVER_UNLOCK ();
 }
-
 BseModule*
 bse_midi_receiver_retrieve_mono_voice (BseMidiReceiver *self,
                                        guint            midi_channel,
                                        BseTrans        *trans)
 {
   MidiChannel *mchannel;
-  
   g_return_val_if_fail (self != NULL, NULL);
   g_return_val_if_fail (midi_channel > 0, NULL);
-  
   BSE_MIDI_RECEIVER_LOCK ();
   mchannel = self->get_channel (midi_channel);
   if (mchannel->vinput)
@@ -1574,7 +1408,6 @@ bse_midi_receiver_retrieve_mono_voice (BseMidiReceiver *self,
   BSE_MIDI_RECEIVER_UNLOCK ();
   return mchannel->vinput->fmodule;
 }
-
 void
 bse_midi_receiver_discard_mono_voice (BseMidiReceiver *self,
                                       guint            midi_channel,
@@ -1582,10 +1415,8 @@ bse_midi_receiver_discard_mono_voice (BseMidiReceiver *self,
                                       BseTrans        *trans)
 {
   MidiChannel *mchannel;
-  
   g_return_if_fail (self != NULL);
   g_return_if_fail (fmodule != NULL);
-  
   BSE_MIDI_RECEIVER_LOCK ();
   mchannel = self->get_channel (midi_channel);
   if (mchannel->vinput && mchannel->vinput->fmodule == fmodule)
@@ -1602,7 +1433,6 @@ bse_midi_receiver_discard_mono_voice (BseMidiReceiver *self,
   BSE_MIDI_RECEIVER_UNLOCK ();
   g_warning ("no such mono synth module: %p", fmodule);
 }
-
 guint
 bse_midi_receiver_create_poly_voice (BseMidiReceiver *self,
                                      guint            midi_channel,
@@ -1610,10 +1440,8 @@ bse_midi_receiver_create_poly_voice (BseMidiReceiver *self,
 {
   MidiChannel *mchannel;
   guint i;
-  
   g_return_val_if_fail (self != NULL, 0);
   g_return_val_if_fail (midi_channel > 0, 0);
-  
   BSE_MIDI_RECEIVER_LOCK ();
   mchannel = self->get_channel (midi_channel);
   /* find free voice slot */
@@ -1628,10 +1456,8 @@ bse_midi_receiver_create_poly_voice (BseMidiReceiver *self,
     }
   mchannel->voices[i] = create_voice_switch_module_L (trans);
   BSE_MIDI_RECEIVER_UNLOCK ();
-  
   return i + 1;
 }
-
 void
 bse_midi_receiver_discard_poly_voice (BseMidiReceiver *self,
                                       guint            midi_channel,
@@ -1640,12 +1466,10 @@ bse_midi_receiver_discard_poly_voice (BseMidiReceiver *self,
 {
   MidiChannel *mchannel;
   VoiceSwitch *vswitch;
-  
   g_return_if_fail (self != NULL);
   g_return_if_fail (midi_channel > 0);
   g_return_if_fail (voice_id > 0);
   voice_id -= 1;
-  
   BSE_MIDI_RECEIVER_LOCK ();
   mchannel = self->get_channel (midi_channel);
   vswitch = voice_id < mchannel->n_voices ? mchannel->voices[voice_id] : NULL;
@@ -1663,7 +1487,6 @@ bse_midi_receiver_discard_poly_voice (BseMidiReceiver *self,
   if (!vswitch)
     g_warning ("MIDI channel %u has no voice %u", midi_channel, voice_id + 1);
 }
-
 BseModule*
 bse_midi_receiver_get_poly_voice_input (BseMidiReceiver   *self,
                                         guint              midi_channel,
@@ -1672,12 +1495,10 @@ bse_midi_receiver_get_poly_voice_input (BseMidiReceiver   *self,
   MidiChannel *mchannel;
   VoiceSwitch *vswitch;
   BseModule *module;
-  
   g_return_val_if_fail (self != NULL, NULL);
   g_return_val_if_fail (midi_channel > 0, NULL);
   g_return_val_if_fail (voice_id > 0, NULL);
   voice_id -= 1;
-  
   BSE_MIDI_RECEIVER_LOCK ();
   mchannel = self->get_channel (midi_channel);
   vswitch = voice_id < mchannel->n_voices ? mchannel->voices[voice_id] : NULL;
@@ -1685,7 +1506,6 @@ bse_midi_receiver_get_poly_voice_input (BseMidiReceiver   *self,
   BSE_MIDI_RECEIVER_UNLOCK ();
   return module;
 }
-
 BseModule*
 bse_midi_receiver_get_poly_voice_output (BseMidiReceiver   *self,
                                          guint              midi_channel,
@@ -1694,12 +1514,10 @@ bse_midi_receiver_get_poly_voice_output (BseMidiReceiver   *self,
   MidiChannel *mchannel;
   VoiceSwitch *vswitch;
   BseModule *module;
-  
   g_return_val_if_fail (self != NULL, NULL);
   g_return_val_if_fail (midi_channel > 0, NULL);
   g_return_val_if_fail (voice_id > 0, NULL);
   voice_id -= 1;
-  
   BSE_MIDI_RECEIVER_LOCK ();
   mchannel = self->get_channel (midi_channel);
   vswitch = voice_id < mchannel->n_voices ? mchannel->voices[voice_id] : NULL;
@@ -1707,7 +1525,6 @@ bse_midi_receiver_get_poly_voice_output (BseMidiReceiver   *self,
   BSE_MIDI_RECEIVER_UNLOCK ();
   return module;
 }
-
 BseModule*
 bse_midi_receiver_create_sub_voice (BseMidiReceiver   *self,
                                     guint              midi_channel,
@@ -1717,12 +1534,10 @@ bse_midi_receiver_create_sub_voice (BseMidiReceiver   *self,
   MidiChannel *mchannel;
   VoiceSwitch *vswitch;
   BseModule *module = NULL;
-  
   g_return_val_if_fail (self != NULL, NULL);
   g_return_val_if_fail (midi_channel > 0, NULL);
   g_return_val_if_fail (voice_id > 0, NULL);
   voice_id -= 1;
-  
   BSE_MIDI_RECEIVER_LOCK ();
   mchannel = self->get_channel (midi_channel);
   vswitch = voice_id < mchannel->n_voices ? mchannel->voices[voice_id] : NULL;
@@ -1737,7 +1552,6 @@ bse_midi_receiver_create_sub_voice (BseMidiReceiver   *self,
   BSE_MIDI_RECEIVER_UNLOCK ();
   return module;
 }
-
 void
 bse_midi_receiver_discard_sub_voice (BseMidiReceiver   *self,
                                      guint              midi_channel,
@@ -1748,13 +1562,11 @@ bse_midi_receiver_discard_sub_voice (BseMidiReceiver   *self,
   MidiChannel *mchannel;
   VoiceSwitch *vswitch;
   guint i, need_unref = FALSE;
-  
   g_return_if_fail (self != NULL);
   g_return_if_fail (midi_channel > 0);
   g_return_if_fail (fmodule != NULL);
   g_return_if_fail (voice_id > 0);
   voice_id -= 1;
-  
   BSE_MIDI_RECEIVER_LOCK ();
   mchannel = self->get_channel (midi_channel);
   vswitch = voice_id < mchannel->n_voices ? mchannel->voices[voice_id] : NULL;
@@ -1785,7 +1597,6 @@ bse_midi_receiver_discard_sub_voice (BseMidiReceiver   *self,
   if (fmodule)
     g_warning ("MIDI channel %u, poly voice %u, no such sub voice: %p", midi_channel, voice_id, fmodule);
 }
-
 gboolean
 bse_midi_receiver_voices_pending (BseMidiReceiver *self,
                                   guint            midi_channel)
@@ -1793,13 +1604,10 @@ bse_midi_receiver_voices_pending (BseMidiReceiver *self,
   MidiChannel *mchannel;
   SfiRing *ring = NULL;
   guint i, active = 0;
-  
   g_return_val_if_fail (self != NULL, FALSE);
   g_return_val_if_fail (midi_channel > 0, FALSE);
-  
   if (self->events)
     return TRUE;
-  
   BSE_MIDI_RECEIVER_LOCK ();
   mchannel = self->get_channel (midi_channel);
   if (mchannel)
@@ -1817,11 +1625,8 @@ bse_midi_receiver_voices_pending (BseMidiReceiver *self,
       active += event->channel == midi_channel;
     }
   BSE_MIDI_RECEIVER_UNLOCK ();
-  
   return active > 0;
 }
-
-
 /* --- event processing --- */
 static inline void
 update_midi_signal_L (BseMidiReceiver  *self,
@@ -1832,7 +1637,6 @@ update_midi_signal_L (BseMidiReceiver  *self,
 		      BseTrans         *trans)
 {
   GSList *signal_modules;
-  
   signal_modules = self->set_control (channel, tick_stamp, signal, value, trans);
   change_midi_control_modules_L (signal_modules, tick_stamp,
                                  signal, value, trans);
@@ -1841,7 +1645,6 @@ update_midi_signal_L (BseMidiReceiver  *self,
 	 signal, value, bse_midi_signal_name (signal));
 #endif
 }
-
 static inline void
 update_midi_signal_continuous_msb_L (BseMidiReceiver  *self,
 				     guint             channel,
@@ -1860,7 +1663,6 @@ update_midi_signal_continuous_msb_L (BseMidiReceiver  *self,
   value = ival / (gfloat) 0x3fff;
   update_midi_signal_L (self, channel, tick_stamp, continuous_signal, value, trans);
 }
-
 static inline void
 update_midi_signal_continuous_lsb_L (BseMidiReceiver  *self,
 				     guint             channel,
@@ -1878,7 +1680,6 @@ update_midi_signal_continuous_lsb_L (BseMidiReceiver  *self,
   value = ival / (gfloat) 0x3fff;
   update_midi_signal_L (self, channel, tick_stamp, continuous_signal, value, trans);
 }
-
 static inline void
 process_midi_control_L (BseMidiReceiver *self,
 			guint            channel,
@@ -1893,17 +1694,14 @@ process_midi_control_L (BseMidiReceiver *self,
    * multiple MIDI signals. extra_continuous are used
    * internally to update only continuous signals.
    */
-  
   if (extra_continuous)
     {
       /* internal BSE_MIDI_SIGNAL_CONTINUOUS_* change */
       update_midi_signal_L (self, channel, tick_stamp, static_cast<BseMidiSignalType> (64 + control), value, trans);
       return;
     }
-  
   /* all MIDI controls are passed literally as BSE_MIDI_SIGNAL_CONTROL_* */
   update_midi_signal_L (self, channel, tick_stamp, static_cast<BseMidiSignalType> (128 + control), value, trans);
-  
   if (control < 32)		/* MSB part of continuous 14bit signal */
     update_midi_signal_continuous_msb_L (self, channel, tick_stamp,
 					 static_cast<BseMidiSignalType> (control + 64),		/* continuous signal */
@@ -1965,17 +1763,14 @@ process_midi_control_L (BseMidiReceiver *self,
       break;
     }
 }
-
 static gint
 midi_receiver_process_event_L (BseMidiReceiver *self,
 			       guint64          max_tick_stamp)
 {
   BseMidiEvent *event;
   gboolean need_wakeup = FALSE;
-  
   if (!self->events)
     return FALSE;
-  
   event = (BseMidiEvent *) self->events->data;
   if (event->delta_time <= max_tick_stamp)
     {
@@ -2065,11 +1860,8 @@ midi_receiver_process_event_L (BseMidiReceiver *self,
     }
   else
     return FALSE;
-  
   if (need_wakeup)
     bse_midi_notifiers_wakeup();
-
   return TRUE;
 }
-
 } // "C"
