@@ -1,45 +1,24 @@
-/* SFK - Synthesis Fusion Kit
- * Copyright (C) 2002 Stefan Westerfeld
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * A copy of the GNU Lesser General Public License should ship along
- * with this library; if not, see http://www.gnu.org/copyleft/.
- */
-#include "bsemain.h"
-#include "bsecategories.h"
-#include "bseprocedure.h"
-#include "bseglue.h"
-#include <sfi/sfiglue.h>
+// Licensed GNU LGPL v2.1 or later: http://www.gnu.org/licenses/lgpl.html
+#include "bsemain.hh"
+#include "bsecategories.hh"
+#include "bseprocedure.hh"
+#include "bseglue.hh"
+#include <sfi/sfiglue.hh>
 #include <stdio.h>
 #include <string.h>
 #include <string>
 #include <set>
-
 std::set<std::string> needTypes;
 std::set<std::string> needClasses;
 std::set<std::string> excludeTypes;
-
 bool silent = false;
-
 void print(const gchar *format, ...)
 {
   va_list args;
-  
   va_start (args, format);
   if (!silent) vfprintf (stdout, format, args);
   va_end (args);
 }
-
-
 std::string removeBse (const std::string& name)
 {
   if (strncmp (name.c_str(), "Bse", 3) == 0)
@@ -49,33 +28,27 @@ std::string removeBse (const std::string& name)
   else
     return name;
 }
-
 std::string getInterface (const std::string& name)
 {
   int i = name.find ("+", 0);
-  
   if(i >= 0)
     {
       std::string result = name.substr (0, i);
       if (strncmp (result.c_str(), "Bse", 3) == 0)
         result = name.substr (3, i-3);
-      
       return result;
     }
   return "";
 }
-
 std::string getMethod (const std::string& name)
 {
   std::string result;
   std::string::const_iterator ni = name.begin ();
-  
   int pos = name.find ("+", 0);
   if (pos >= 0)
     ni += pos + 1;
   else if (name.size () > 4)
     ni += 4; /* assume & skip bse prefix */
-  
   while (ni != name.end ())
     {
       if (*ni == '-')
@@ -86,13 +59,11 @@ std::string getMethod (const std::string& name)
     }
   return result;
 }
-
 std::string
 signalName (const std::string& signal)
 {
   std::string result;
   std::string::const_iterator si = signal.begin ();
-  
   while (si != signal.end ())
     {
       if (*si == '-')
@@ -103,7 +74,6 @@ signalName (const std::string& signal)
     }
   return result;
 }
-
 std::string paramName (const std::string& name)
 {
   std::string result;
@@ -118,16 +88,13 @@ std::string paramName (const std::string& name)
     }
   return result;
 }
-
 std::string activeInterface = "";
 int indent = 0;
-
 void printIndent ()
 {
   for (int i = 0; i < indent; i++)
     print("  ");
 }
-
 void setActiveInterface (const std::string& x, const std::string& parent)
 {
   if (activeInterface != x)
@@ -138,15 +105,13 @@ void setActiveInterface (const std::string& x, const std::string& parent)
           printIndent ();
           print ("};\n\n");
         }
-      
       activeInterface = x;
-      
       if (activeInterface != "")
         {
           printIndent ();
           if (needTypes.count("Bse" + activeInterface) > 0)
             needClasses.insert(activeInterface);
-          print ("class %s", activeInterface.c_str ());
+          print ("interface %s", activeInterface.c_str ());
           if (parent != "")
             print (" : %s", parent.c_str());
           print (" {\n");
@@ -154,11 +119,9 @@ void setActiveInterface (const std::string& x, const std::string& parent)
         }
     }
 }
-
 std::string idlType (GType g)
 {
   std::string s = g_type_name (g);
-  
   if (s[0] == 'B' && s[1] == 's' && s[2] == 'e')
     {
       needTypes.insert (s);
@@ -183,22 +146,18 @@ std::string idlType (GType g)
       return "*ERROR*";
     }
 }
-
 std::string symbolForInt (int i)
 {
   if (i == SFI_MAXINT) return "SFI_MAXINT";
   if (i == SFI_MININT) return "SFI_MININT";
-  
   char *x = g_strdup_printf ("%d", i);
   std::string result = x;
   g_free(x);
   return result;
 }
-
 void printPSpec (const char *dir, GParamSpec *pspec)
 {
   std::string pname = paramName (pspec->name);
-  
   printIndent ();
   print ("%-4s%-20s= (\"%s\", \"%s\", ",
          dir,
@@ -206,14 +165,11 @@ void printPSpec (const char *dir, GParamSpec *pspec)
          g_param_spec_get_nick (pspec) ?  g_param_spec_get_nick (pspec) : "",
          g_param_spec_get_blurb (pspec) ?  g_param_spec_get_blurb (pspec) : ""
          );
-  
   if (SFI_IS_PSPEC_INT (pspec))
     {
       int default_value, minimum, maximum, stepping_rate;
-      
       default_value = sfi_pspec_get_int_default (pspec);
       sfi_pspec_get_int_range (pspec, &minimum, &maximum, &stepping_rate);
-      
       print("%s, %s, %s, %s, ", symbolForInt (default_value).c_str(),
             symbolForInt (minimum).c_str(), symbolForInt (maximum).c_str(),
             symbolForInt (stepping_rate).c_str());
@@ -221,36 +177,30 @@ void printPSpec (const char *dir, GParamSpec *pspec)
   if (SFI_IS_PSPEC_BOOL (pspec))
     {
       GParamSpecBoolean *bspec = G_PARAM_SPEC_BOOLEAN (pspec);
-      
       print("%s, ", bspec->default_value ? "TRUE" : "FALSE");
     }
   print("\":flagstodo\");\n");
 }
-
 void printMethods (const std::string& iface)
 {
   BseCategorySeq *cseq;
   guint i;
-  
   cseq = bse_categories_match_typed ("*", BSE_TYPE_PROCEDURE);
   for (i = 0; i < cseq->n_cats; i++)
     {
       GType type_id = g_type_from_name (cseq->cats[i]->type);
       const gchar *blurb = bse_type_get_blurb (type_id);
       BseProcedureClass *klass = (BseProcedureClass *)g_type_class_ref (type_id);
-      
       /* procedures */
       std::string t = cseq->cats[i]->type;
       std::string iname = getInterface (t);
       std::string mname = getMethod (t);
       std::string rtype = klass->n_out_pspecs ?
                           idlType (klass->out_pspecs[0]->value_type) : "void";
-      
       if (iname == iface)
 	{
 	  /* for methods, the first argument is implicit: the object itself */
 	  guint first_p = iface == "" ? 0 : 1;
-          
 	  printIndent ();
 	  print ("%s %s (", rtype.c_str(), mname.c_str ());
 	  for (guint p = first_p; p < klass->n_in_pspecs; p++)
@@ -263,7 +213,6 @@ void printMethods (const std::string& iface)
 	    }
 	  print(") {\n");
 	  indent++;
-          
 	  if (blurb)
 	    {
 	      char *ehelp = g_strescape (blurb, 0);
@@ -271,13 +220,10 @@ void printMethods (const std::string& iface)
 	      print ("Info help = \"%s\";\n", ehelp);
 	      g_free (ehelp);
 	    }
-          
 	  for (guint p = first_p; p < klass->n_in_pspecs; p++)
 	    printPSpec ("In", klass->in_pspecs[p]);
-          
 	  for (guint p = 0; p < klass->n_out_pspecs; p++)
 	    printPSpec ("Out", klass->out_pspecs[p]);
-          
 	  indent--;
 	  printIndent ();
 	  print ("}\n");
@@ -286,18 +232,14 @@ void printMethods (const std::string& iface)
     }
   bse_category_seq_free (cseq);
 }
-
 /* FIXME: we might want to have a sfi_glue_iface_parent () method */
 void printInterface (const std::string& iface, const std::string& parent = "")
 {
   std::string idliface = removeBse (iface);
-
   if (excludeTypes.count (iface))
     return;
-
   setActiveInterface (idliface, parent);
   printMethods (idliface);
-  
   if (iface != "")
     {
       /* signals */
@@ -310,17 +252,14 @@ void printInterface (const std::string& iface, const std::string& parent = "")
 	    {
 	      GSignalQuery query;
 	      g_signal_query (sids[s], &query);
-
               // FIXME: some core types are implemented as plugins, and thus have
               // class destructors that are executed right after type registration.
               // that's why we can't query their signals here
               if (!query.signal_id)
                 continue;
-
 	      // FIXME: how to deal with Bse::MidiEvent?
 	      if (signalName (query.signal_name) == "midi_event")
 		continue;
-
 	      printIndent();
 	      print ("signal %s (", signalName (query.signal_name).c_str());
 	      for (guint p = 0; p < query.n_params; p++)
@@ -338,14 +277,12 @@ void printInterface (const std::string& iface, const std::string& parent = "")
 	{
 	  print("/* type %s (%s) is not instantiatable */\n", g_type_name (type_id), iface.c_str());
 	}
-     
       /* properties */
       GObjectClass *klass = (GObjectClass *)g_type_class_ref (type_id);
       if (klass)
 	{
 	  guint n_properties = 0;
 	  GParamSpec **properties = g_object_class_list_properties (klass, &n_properties);
-	 
 	  for (guint i = 0; i < n_properties; i++)
 	    {
 	      if (properties[i]->owner_type == type_id)
@@ -354,19 +291,16 @@ void printInterface (const std::string& iface, const std::string& parent = "")
 	  g_free (properties);
 	  g_type_class_unref (klass);
 	}
-
       const gchar **children = sfi_glue_iface_children (iface.c_str());
       while (*children)
         printInterface (*children++, idliface);
     }
 }
-
 static void
 printChoices (void)
 {
   GType *children;
   guint n, i;
-  
   children = g_type_children (G_TYPE_ENUM, &n);
   for (i = 0; i < n; i++)
     {
@@ -374,22 +308,21 @@ printChoices (void)
       GEnumClass *eclass = (GEnumClass *)g_type_class_ref (children[i]);
       gboolean regular_choice = strcmp (name, "BseErrorType") != 0;
       GEnumValue *val;
-
       if (needTypes.count (name) && !excludeTypes.count (name))
 	{
 	  /* enum definition */
 	  printIndent ();
-	  print ("choice %s {\n", removeBse(name).c_str());
+	  print ("enum %s {\n", removeBse(name).c_str());
           indent++;
 	  for (val = eclass->values; val->value_name; val++)
 	    {
 	      bool neutral = (!regular_choice && val == eclass->values);
 	      printIndent();
               if (neutral)
-                print ("%s = (Neutral, \"%s\"),\n", removeBse (val->value_name).c_str(),
+                print ("%s = Enum (0, \"%s\"),\n", removeBse (val->value_name).c_str(),
                        val->value_nick);
               else
-                print ("%s = (%d, \"%s\"),\n", removeBse (val->value_name).c_str(),
+                print ("%s = Enum (%d, \"%s\"),\n", removeBse (val->value_name).c_str(),
                        val->value, val->value_nick);
 	    }
           indent--;
@@ -401,19 +334,16 @@ printChoices (void)
     }
   g_free (children);
 }
-
 void
 printForwardDecls ()
 {
   std::set<std::string>::iterator ci;
-  
   for (ci = needClasses.begin(); ci != needClasses.end(); ci++)
     {
       printIndent();
-      print ("class %s;\n", ci->c_str());
+      print ("interface %s;\n", ci->c_str());
     }
 }
-
 int
 main (int argc, char **argv)
 {
@@ -436,17 +366,14 @@ main (int argc, char **argv)
     }
   g_thread_init (NULL);
   bse_init_inprocess (&argc, &argv, "BseProcIDL", NULL);
-  
   sfi_glue_context_push (bse_glue_context_intern ("BseProcIdl"));
   std::string s = sfi_glue_base_iface ();
-  
   /* small hackery to collect all enum types that need to be printed */
   silent = true;
   // needTypes.insert (g_type_name (BSE_TYPE_MIDI_SIGNAL_TYPE));
   printInterface (s);
   printInterface ("");
   silent = false;
-  
   print ("namespace Bse {\n");
   indent++;
   printChoices ();
@@ -455,9 +382,6 @@ main (int argc, char **argv)
   printInterface ("");  /* prints procedures without interface */
   indent--;
   print ("};\n");
-  
-  
   sfi_glue_context_pop ();
 }
-
 /* vim:set ts=8 sts=2 sw=2: */
