@@ -1,21 +1,4 @@
-/* SFI - Synthesis Fusion Kit Interface
- * Copyright (C) 2002-2003 Stefan Westerfeld
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General
- * Public License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
- */
+// Licensed GNU LGPL v2.1 or later: http://www.gnu.org/licenses/lgpl.html
 #include "sfidl-clientcxx.hh"
 #include "sfidl-factory.hh"
 #include <fcntl.h>
@@ -26,13 +9,11 @@
 #include "sfidl-namespace.hh"
 #include "sfidl-options.hh"
 #include "sfidl-parser.hh"
-#include "sfiparams.h" /* scatId (SFI_SCAT_*) */
-
+#include "sfiparams.hh" /* scatId (SFI_SCAT_*) */
 using namespace Sfidl;
-using namespace std;
-
-string
-CodeGeneratorClientCxx::typeArg (const string& type)
+using std::make_pair;
+String
+CodeGeneratorClientCxx::typeArg (const String& type)
 {
   switch (parser.typeOf (type))
     {
@@ -44,9 +25,8 @@ CodeGeneratorClientCxx::typeArg (const string& type)
       default:	      return CodeGeneratorCBase::typeArg (type);
     }
 }
-
-string
-CodeGeneratorClientCxx::typeField (const string& type)
+String
+CodeGeneratorClientCxx::typeField (const String& type)
 {
   switch (parser.typeOf (type))
     {
@@ -58,9 +38,8 @@ CodeGeneratorClientCxx::typeField (const string& type)
       default:	      return CodeGeneratorCBase::typeArg (type);
     }
 }
-
-string
-CodeGeneratorClientCxx::typeRet (const string& type)
+String
+CodeGeneratorClientCxx::typeRet (const String& type)
 {
   switch (parser.typeOf (type))
     {
@@ -72,9 +51,8 @@ CodeGeneratorClientCxx::typeRet (const string& type)
       default:	      return CodeGeneratorCBase::typeArg (type);
     }
 }
-
-string
-CodeGeneratorClientCxx::funcNew (const string& type)
+String
+CodeGeneratorClientCxx::funcNew (const String& type)
 {
   switch (parser.typeOf (type))
     {
@@ -82,9 +60,8 @@ CodeGeneratorClientCxx::funcNew (const string& type)
       default:	      return CodeGeneratorCBase::funcNew (type);
     }
 }
-
-string
-CodeGeneratorClientCxx::funcCopy (const string& type)
+String
+CodeGeneratorClientCxx::funcCopy (const String& type)
 {
   switch (parser.typeOf (type))
     {
@@ -92,9 +69,8 @@ CodeGeneratorClientCxx::funcCopy (const string& type)
       default:	      return CodeGeneratorCBase::funcCopy (type);
     }
 }
-
-string
-CodeGeneratorClientCxx::funcFree (const string& type)
+String
+CodeGeneratorClientCxx::funcFree (const String& type)
 {
   switch (parser.typeOf (type))
     {
@@ -102,9 +78,8 @@ CodeGeneratorClientCxx::funcFree (const string& type)
       default:	      return CodeGeneratorCBase::funcFree (type);
     }
 }
-
-string CodeGeneratorClientCxx::createTypeCode (const std::string& type, const std::string& name, 
-				             TypeCodeModel model)
+String CodeGeneratorClientCxx::createTypeCode (const String& type, const String& name, 
+				               TypeCodeModel model)
 {
   /* FIXME: parameter validation */
   switch (parser.typeOf (type))
@@ -163,13 +138,11 @@ string CodeGeneratorClientCxx::createTypeCode (const std::string& type, const st
     }
   return CodeGeneratorCBase::createTypeCode (type, name, model);
 }
-
 static const char*
-cUC_NAME (const string &cstr) // FIXME: need mammut renaming function
+cUC_NAME (const String &cstr) // FIXME: need mammut renaming function
 {
   return g_intern_string (cstr.c_str());
 }
-
 void
 CodeGeneratorClientCxx::printChoicePrototype (NamespaceHelper& nspace)
 {
@@ -179,12 +152,11 @@ CodeGeneratorClientCxx::printChoicePrototype (NamespaceHelper& nspace)
       if (parser.fromInclude (ci->name))
         continue;
       nspace.setFromSymbol(ci->name);
-      string name = nspace.printableForm (ci->name);
+      String name = nspace.printableForm (ci->name);
       printf ("\n");
       printf ("static inline SfiChoiceValues %s_choice_values();\n", name.c_str());
     }
 }
-
 void
 CodeGeneratorClientCxx::printChoiceImpl (NamespaceHelper& nspace)
 {
@@ -194,7 +166,7 @@ CodeGeneratorClientCxx::printChoiceImpl (NamespaceHelper& nspace)
       if (parser.fromInclude (ci->name))
         continue;
       nspace.setFromSymbol(ci->name);
-      string name = nspace.printableForm (ci->name);
+      String name = nspace.printableForm (ci->name);
       printf ("\n");
       printf ("static inline SfiChoiceValues\n");
       printf ("%s_choice_values()\n", name.c_str());
@@ -210,60 +182,45 @@ CodeGeneratorClientCxx::printChoiceImpl (NamespaceHelper& nspace)
       printf ("}\n\n");
     }
 }
-
 void
 CodeGeneratorClientCxx::printRecSeqForwardDecl (NamespaceHelper& nspace)
 {
   vector<Sequence>::const_iterator si;
   vector<Record>::const_iterator ri;
-
   printf ("\n/* record/sequence prototypes */\n");
-
   /* forward declarations for records */
   for (ri = parser.getRecords().begin(); ri != parser.getRecords().end(); ri++)
     {
       if (parser.fromInclude (ri->name))
         continue;
-
       nspace.setFromSymbol(ri->name);
-      string name = nspace.printableForm (ri->name);
-
+      String name = nspace.printableForm (ri->name);
       printf("\n");
       printf("class %s;\n", name.c_str());
       printf("typedef Sfi::RecordHandle<%s> %sHandle;\n", name.c_str(), name.c_str());
     }
-
   /* forward declarations for sequences */
   for (si = parser.getSequences().begin(); si != parser.getSequences().end(); si++)
     {
       if (parser.fromInclude (si->name)) continue;
-
       nspace.setFromSymbol(si->name);
-      string name = nspace.printableForm (si->name);
-
+      String name = nspace.printableForm (si->name);
       printf("\n");
       printf("class %s;\n", name.c_str());
     }
 }
-
 void CodeGeneratorClientCxx::printRecSeqDefinition (NamespaceHelper& nspace)
 {
   vector<Param>::const_iterator pi;
-
   printf ("\n/* record/sequence definitions */\n");
-
   /* sequences */
   for (vector<Sequence>::const_iterator si = parser.getSequences().begin(); si != parser.getSequences().end(); si++)
     {
       if (parser.fromInclude (si->name)) continue;
-
       nspace.setFromSymbol(si->name);
-
       /* FIXME: need optimized refcounted copy-on-write sequences as base types */
-
-      string name = nspace.printableForm (si->name);
-      string content = typeField (si->content.type);
-      
+      String name = nspace.printableForm (si->name);
+      String content = typeField (si->content.type);
       printf ("\n");
       printf ("class %s : public Sfi::Sequence<%s> {\n", name.c_str(), content.c_str());
       printf ("public:\n");
@@ -276,16 +233,13 @@ void CodeGeneratorClientCxx::printRecSeqDefinition (NamespaceHelper& nspace)
       printf("};\n");
       printf ("\n");
     }
-
   /* records */
   for (vector<Record>::const_iterator ri = parser.getRecords().begin(); ri != parser.getRecords().end(); ri++)
     {
       if (parser.fromInclude (ri->name)) continue;
-
       nspace.setFromSymbol(ri->name);
-      string name = nspace.printableForm (ri->name);
-      string type_name = makeMixedName (ri->name).c_str();
-
+      String name = nspace.printableForm (ri->name);
+      String type_name = makeMixedName (ri->name).c_str();
       printf ("\n");
       printf ("class %s : public ::Sfi::GNewable {\n", name.c_str());
       printf ("public:\n");
@@ -303,22 +257,19 @@ void CodeGeneratorClientCxx::printRecSeqDefinition (NamespaceHelper& nspace)
       printf ("\n");
     }
 }
-
 void CodeGeneratorClientCxx::printRecSeqImpl (NamespaceHelper& nspace)
 {
   printf ("\n/* record/sequence implementations */\n");
-
   /* sequence members */
   for (vector<Sequence>::const_iterator si = parser.getSequences().begin(); si != parser.getSequences().end(); si++)
     {
       if (parser.fromInclude (si->name))
         continue;
       nspace.setFromSymbol(si->name);
-      string name = nspace.printableForm (si->name);
-      string nname = si->name;
-      string type_name = makeMixedName (si->name).c_str();
-
-      string elementFromValue = createTypeCode (si->content.type, "element", MODEL_FROM_VALUE);
+      String name = nspace.printableForm (si->name);
+      String nname = si->name;
+      String type_name = makeMixedName (si->name).c_str();
+      String elementFromValue = createTypeCode (si->content.type, "element", MODEL_FROM_VALUE);
       printf("%s\n", cTypeRet (si->name));
       printf("%s::from_seq (SfiSeq *sfi_seq)\n", nname.c_str());
       printf("{\n");
@@ -336,8 +287,7 @@ void CodeGeneratorClientCxx::printRecSeqImpl (NamespaceHelper& nspace)
       printf("  }\n");
       printf("  return seq;\n");
       printf("}\n\n");
-
-      string elementToValue = createTypeCode (si->content.type, "seq[i]", MODEL_TO_VALUE);
+      String elementToValue = createTypeCode (si->content.type, "seq[i]", MODEL_TO_VALUE);
       printf("SfiSeq *\n");
       printf("%s::to_seq (%s seq)\n", nname.c_str(), cTypeArg (si->name));
       printf("{\n");
@@ -350,7 +300,6 @@ void CodeGeneratorClientCxx::printRecSeqImpl (NamespaceHelper& nspace)
       printf("  }\n");
       printf("  return sfi_seq;\n");
       printf("}\n\n");
-
       printf ("%s\n", cTypeRet (si->name));
       printf ("%s::value_get_seq (const GValue *value)\n", nname.c_str());
       printf ("{\n");
@@ -362,17 +311,15 @@ void CodeGeneratorClientCxx::printRecSeqImpl (NamespaceHelper& nspace)
       printf ("  ::Sfi::cxx_value_set_seq< %s> (value, self);\n", nname.c_str());
       printf ("}\n\n");
     }
-
   /* record members */
   for (vector<Record>::const_iterator ri = parser.getRecords().begin(); ri != parser.getRecords().end(); ri++)
     {
       if (parser.fromInclude (ri->name))
         continue;
       nspace.setFromSymbol(ri->name);
-      string name = nspace.printableForm (ri->name);
-      string nname = ri->name;
-      string type_name = makeMixedName (ri->name).c_str();
-      
+      String name = nspace.printableForm (ri->name);
+      String nname = ri->name;
+      String type_name = makeMixedName (ri->name).c_str();
       printf("%s\n", cTypeRet (ri->name));
       printf("%s::from_rec (SfiRec *sfi_rec)\n", nname.c_str());
       printf("{\n");
@@ -384,15 +331,13 @@ void CodeGeneratorClientCxx::printRecSeqImpl (NamespaceHelper& nspace)
       printf("  %s rec = Sfi::INIT_DEFAULT;\n", cTypeField (ri->name));
       for (vector<Param>::const_iterator pi = ri->contents.begin(); pi != ri->contents.end(); pi++)
 	{
-	  string elementFromValue = createTypeCode (pi->type, "element", MODEL_FROM_VALUE);
-
+	  String elementFromValue = createTypeCode (pi->type, "element", MODEL_FROM_VALUE);
 	  printf("  element = sfi_rec_get (sfi_rec, \"%s\");\n", pi->name.c_str());
 	  printf("  if (element)\n");
 	  printf("    rec->%s = %s;\n", pi->name.c_str(), elementFromValue.c_str());
 	}
       printf("  return rec;\n");
       printf("}\n\n");
-
       printf("SfiRec *\n");
       printf("%s::to_rec (%s rec)\n", nname.c_str(), cTypeArg (ri->name));
       printf("{\n");
@@ -405,14 +350,13 @@ void CodeGeneratorClientCxx::printRecSeqImpl (NamespaceHelper& nspace)
       printf("  sfi_rec = sfi_rec_new ();\n");
       for (vector<Param>::const_iterator pi = ri->contents.begin(); pi != ri->contents.end(); pi++)
 	{
-	  string elementToValue = createTypeCode (pi->type, "rec->" + pi->name, MODEL_TO_VALUE);
+	  String elementToValue = createTypeCode (pi->type, "rec->" + pi->name, MODEL_TO_VALUE);
 	  printf("  element = %s;\n", elementToValue.c_str());
 	  printf("  sfi_rec_set (sfi_rec, \"%s\", element);\n", pi->name.c_str());
 	  printf("  sfi_value_free (element);\n");        // FIXME: couldn't we have take_set
 	}
       printf("  return sfi_rec;\n");
       printf("}\n\n");
-
       printf ("%s\n", cTypeRet(ri->name));
       printf ("%s::value_get_rec (const GValue *value)\n", nname.c_str());
       printf ("{\n");
@@ -425,69 +369,55 @@ void CodeGeneratorClientCxx::printRecSeqImpl (NamespaceHelper& nspace)
       printf ("}\n\n");
     }
 }
-
 bool CodeGeneratorClientCxx::run ()
 {
   vector<Choice>::const_iterator ei;
   vector<Param>::const_iterator pi;
   vector<Class>::const_iterator ci;
   vector<Method>::const_iterator mi;
- 
   printf("\n/*-------- begin %s generated code --------*/\n\n\n", options.sfidlName.c_str());
-
   if (generateHeader)
     {
       /* choices */
       for(ei = parser.getChoices().begin(); ei != parser.getChoices().end(); ei++)
         {
           if (parser.fromInclude (ei->name)) continue;
-
           nspace.setFromSymbol (ei->name);
-
           printf("\nenum %s {\n", nspace.printableForm (ei->name).c_str());
           for (vector<ChoiceValue>::const_iterator ci = ei->contents.begin(); ci != ei->contents.end(); ci++)
             {
               /* don't export server side assigned choice values to the client */
-              string ename = makeUpperName (nspace.printableForm (ci->name));
+              String ename = makeUpperName (nspace.printableForm (ci->name));
               printf("  %s = %d,\n", ename.c_str(), ci->sequentialValue);
             }
           printf("};\n");
 	}
       nspace.leaveAll();
-
       /* choice converters */
       for(ei = parser.getChoices().begin(); ei != parser.getChoices().end(); ei++)
 	{
-	  string name = nspace.printableForm (ei->name);
-	  string lname = makeLowerName (ei->name);
-
+	  String name = nspace.printableForm (ei->name);
+	  String lname = makeLowerName (ei->name);
 	  printf("const gchar* %s_to_choice (%s value);\n", lname.c_str(), name.c_str());
 	  printf("%s %s_from_choice (const gchar *choice);\n", name.c_str(), lname.c_str());
         }
-
       printf("\n");
       /* prototypes for classes */
       for (ci = parser.getClasses().begin(); ci != parser.getClasses().end(); ci++)
 	{
 	  if (parser.fromInclude (ci->name)) continue;
-
 	  nspace.setFromSymbol (ci->name);
-	  string name = nspace.printableForm (ci->name);
-
+	  String name = nspace.printableForm (ci->name);
 	  printf("class %s;\n", name.c_str());
 	}
-
       printRecSeqForwardDecl (nspace);
-
       /* classes */
       for (ci = parser.getClasses().begin(); ci != parser.getClasses().end(); ci++)
 	{
 	  if (parser.fromInclude (ci->name)) continue;
-
 	  nspace.setFromSymbol (ci->name);
-	  string name = nspace.printableForm (ci->name);
-
-	  string init;
+	  String name = nspace.printableForm (ci->name);
+	  String init;
 	  printf("\n");
 	  if (ci->inherits == "")
 	    {
@@ -515,13 +445,11 @@ bool CodeGeneratorClientCxx::run ()
       printRecSeqDefinition (nspace);
       printRecSeqImpl (nspace);
     }
-
   if (generateSource)
     {
       /* choice utils */
       printChoiceConverters();
       printf("\n");
-
       /* methods */
       for (ci = parser.getClasses().begin(); ci != parser.getClasses().end(); ci++)
 	{
@@ -530,12 +458,10 @@ bool CodeGeneratorClientCxx::run ()
 	  printProperties(*ci);
 	}
     }
-
   printf("\n");
   for (mi = parser.getProcedures().begin(); mi != parser.getProcedures().end(); mi++)
     {
       if (parser.fromInclude (mi->name)) continue;
-
       if (generateHeader)
 	nspace.setFromSymbol (mi->name);
       printProcedure (*mi, generateHeader);
@@ -543,11 +469,9 @@ bool CodeGeneratorClientCxx::run ()
   printf("\n");
   nspace.leaveAll();
   printf("\n/*-------- end %s generated code --------*/\n\n\n", options.sfidlName.c_str());
-
   return 1;
 }
-
-string CodeGeneratorClientCxx::makeProcName (const string& className, const string& procName)
+String CodeGeneratorClientCxx::makeProcName (const String& className, const String& procName)
 {
   if (className == "")
     {
@@ -562,48 +486,40 @@ string CodeGeneratorClientCxx::makeProcName (const string& className, const stri
 	return className + "::" + makeStyleName (procName);
     }
 }
-
 void CodeGeneratorClientCxx::printMethods (const Class& cdef)
 {
   vector<Method>::const_iterator mi;
   vector<Param>::const_iterator pi;
   bool proto = generateHeader;
-
   for (mi = cdef.methods.begin(); mi != cdef.methods.end(); mi++)
     {
       Method md;
       md.name = mi->name;
       md.result = mi->result;
-
       Param class_as_param;
       class_as_param.name = "_object_id";
       class_as_param.type = cdef.name;
       md.params.push_back (class_as_param);
-
       for(pi = mi->params.begin(); pi != mi->params.end(); pi++)
 	md.params.push_back (*pi);
-
       if (proto) printf ("  ");
       printProcedure (md, proto, cdef.name);
     }
 }
-
 void CodeGeneratorClientCxx::printProperties (const Class& cdef)
 {
   vector<Param>::const_iterator pi;
   bool proto = generateHeader;
-
   for (pi = cdef.properties.begin(); pi != cdef.properties.end(); pi++)
     {
-      string setProperty = makeStyleName ("set_" + pi->name);
-      string getProperty = makeStyleName (pi->name);
-      string newName = makeLowerName ("new_" + pi->name);
-      string propName = makeLowerName (pi->name, '-');
-      string ret = typeRet (pi->type);
+      String setProperty = makeStyleName ("set_" + pi->name);
+      String getProperty = makeStyleName (pi->name);
+      String newName = makeLowerName ("new_" + pi->name);
+      String propName = makeLowerName (pi->name, '-');
+      String ret = typeRet (pi->type);
       if (proto) {
 	/* property getter */
 	printf ("  %s %s ();\n", ret.c_str(), getProperty.c_str());
-
 	/* property setter */
 	printf ("  void %s (%s %s);\n", setProperty.c_str(), cTypeArg (pi->type), newName.c_str());
       }
@@ -622,7 +538,7 @@ void CodeGeneratorClientCxx::printProperties (const Class& cdef)
 	printf ("%s::%s (%s %s)\n", cdef.name.c_str(), setProperty.c_str(),
 				    cTypeArg (pi->type), newName.c_str());
 	printf ("{\n");
-	string to_val = createTypeCode (pi->type, newName, MODEL_TO_VALUE).c_str();
+	String to_val = createTypeCode (pi->type, newName, MODEL_TO_VALUE).c_str();
 	printf ("  GValue *val = %s;\n", to_val.c_str());
 	printf ("  sfi_glue_proxy_set_property (_proxy(), \"%s\", val);\n", propName.c_str());
 	printf ("  sfi_value_free (val);\n");
@@ -631,20 +547,16 @@ void CodeGeneratorClientCxx::printProperties (const Class& cdef)
       }
     }
 }
-
 OptionVector
 CodeGeneratorClientCxx::getOptions()
 {
   OptionVector opts = CodeGeneratorCxxBase::getOptions();
-
   opts.push_back (make_pair ("--lower", false));
   opts.push_back (make_pair ("--mixed", false));
-
   return opts;
 }
-
 void
-CodeGeneratorClientCxx::setOption (const string& option, const string& value)
+CodeGeneratorClientCxx::setOption (const String& option, const String& value)
 {
   if (option == "--lower")
     {
@@ -659,7 +571,6 @@ CodeGeneratorClientCxx::setOption (const string& option, const string& value)
       CodeGeneratorCxxBase::setOption (option, value);
     }
 }
-
 void
 CodeGeneratorClientCxx::help()
 {
@@ -670,27 +581,21 @@ CodeGeneratorClientCxx::help()
   fprintf (stderr, " --namespace <namespace>     set the namespace to use for the code\n");
 */
 }
-
-string CodeGeneratorClientCxx::makeStyleName (const string& name)
+String CodeGeneratorClientCxx::makeStyleName (const String& name)
 {
   if (style == STYLE_MIXED)
     return makeLMixedName (name);
   return makeLowerName (name);
 }
-
-
 namespace {
-
 class ClientCxxFactory : public Factory {
 public:
-  string option() const	      { return "--client-cxx"; }
-  string description() const  { return "generate client C++ language binding"; }
-
+  String option() const	      { return "--client-cxx"; }
+  String description() const  { return "generate client C++ language binding"; }
   CodeGenerator *create (const Parser& parser) const
   {
     return new CodeGeneratorClientCxx (parser);
   }
 } cxx_factory;
-
 }
 /* vim:set ts=8 sts=2 sw=2: */
