@@ -1,84 +1,62 @@
-/* SFI - Synthesis Fusion Kit Interface
- * Copyright (C) 2002 Stefan Westerfeld
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General
- * Public License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
- */
-#include "sfidl-corec.hh"
+// Licensed GNU LGPL v2.1 or later: http://www.gnu.org/licenses/lgpl.html
+#include "sfidl-utils.hh"
 #include "sfidl-factory.hh"
+#include "sfidl-generator.hh"
 #include <fcntl.h>
 #include <stdio.h>
 #include <unistd.h>
 #include <errno.h>
 #include <ctype.h>
-
 namespace {
-
 using namespace Sfidl;
-using namespace std;
-
+using std::make_pair;
 class CodeGeneratorCoreC : public CodeGenerator {
   const char*
-  intern (const string &str)
+  intern (const String &str)
   {
     return g_intern_string (str.c_str());
   }
   const char*
-  make_type_id_symbol (const string &type_name,
-                       const string &append = "")
+  make_type_id_symbol (const String &type_name,
+                       const String &append = "")
   {
-    vector<string> insertions;
+    vector<String> insertions;
     insertions.push_back ("_type_id_");
-    string s = rename (ABSOLUTE, type_name, lower, "_", insertions, lower, "_");
+    String s = rename (ABSOLUTE, type_name, lower, "_", insertions, lower, "_");
     s += append;
     return intern (s);
   }
   const char*
-  make_TYPE_MACRO (const string &type_name,
-                   const string &append = "")
+  make_TYPE_MACRO (const String &type_name,
+                   const String &append = "")
   {
-    vector<string> insertions;
+    vector<String> insertions;
     insertions.push_back ("TYPE");
-    string s = rename (ABSOLUTE, type_name, UPPER, "_", insertions, UPPER, "_");
+    String s = rename (ABSOLUTE, type_name, UPPER, "_", insertions, UPPER, "_");
     s += append;
     return intern (s);
   }
   const char*
-  make_fqtn (const string &type_name,
-             const string &append = "")
+  make_fqtn (const String &type_name,
+             const String &append = "")
   {
-    vector<string> empty;
-    string s = rename (ABSOLUTE, type_name, Capitalized, "::", empty, Capitalized, "");
+    vector<String> empty;
+    String s = rename (ABSOLUTE, type_name, Capitalized, "::", empty, Capitalized, "");
     s += append;
     return intern (s);
   }
-  std::string generateInitFunction;
+  String generateInitFunction;
   void
-  printInfoStrings (const string&              name,
-                    const Map<string,IString> &infos)
+  printInfoStrings (const String&              name,
+                    const Map<String,IString> &infos)
   {
     printf ("static const gchar *%s[] = {\n", name.c_str());
-    
-    Map<string,IString>::const_iterator ii;
+    Map<String,IString>::const_iterator ii;
     for (ii = infos.begin(); ii != infos.end(); ii++)
       printf ("  \"%s=%s\",\n", ii->first.c_str(), ii->second.c_str());
-    
     printf ("  NULL,\n");
     printf ("};\n");
   }
-  
   void
   help()
   {
@@ -89,14 +67,12 @@ class CodeGeneratorCoreC : public CodeGenerator {
   getOptions()
   {
     OptionVector opts = CodeGenerator::getOptions();
-    
     opts.push_back (make_pair ("--init", true));
-    
     return opts;
   }
   void
-  setOption (const string &option,
-             const string &value)
+  setOption (const String &option,
+             const String &value)
   {
     if (option == "--init")
       {
@@ -107,18 +83,17 @@ class CodeGeneratorCoreC : public CodeGenerator {
         CodeGenerator::setOption (option, value);
       }
   }
-
   const char*
-  TypeName (const string &type_name,
-            const string &append = "")
+  TypeName (const String &type_name,
+            const String &append = "")
   {
-    vector<string> empty;
-    string s = rename (ABSOLUTE, type_name, Capitalized, "", empty, Capitalized, "");
+    vector<String> empty;
+    String s = rename (ABSOLUTE, type_name, Capitalized, "", empty, Capitalized, "");
     s += append;
     return intern (s);
   }
   const char*
-  TypeField (const string &type)
+  TypeField (const String &type)
   {
     switch (parser.typeOf (type))
       {
@@ -139,7 +114,7 @@ class CodeGeneratorCoreC : public CodeGenerator {
       }
   }
   const char*
-  TypeArg (const string &type)
+  TypeArg (const String &type)
   {
     switch (parser.typeOf (type))
       {
@@ -148,7 +123,7 @@ class CodeGeneratorCoreC : public CodeGenerator {
       }
   }
   const char*
-  TypeRet (const string& type)
+  TypeRet (const String& type)
   {
     switch (parser.typeOf (type))
       {
@@ -156,14 +131,14 @@ class CodeGeneratorCoreC : public CodeGenerator {
       }
   }
   const char*
-  cxx_handle (const string &type,
-              const string &var)
+  cxx_handle (const String &type,
+              const String &var)
   {
     switch (parser.typeOf (type))
       {
       case RECORD:
         {
-          string s, cxxtype = string() + make_fqtn (type) + "Handle";
+          String s, cxxtype = String() + make_fqtn (type) + "Handle";
           /* generate: (var ? FooHandle(*var) : FooHandle(INIT_NULL)) */
           s = "(" +
               var + " ? " +
@@ -176,12 +151,12 @@ class CodeGeneratorCoreC : public CodeGenerator {
       default:          return intern (var);
       }
   }
-  string
+  String
   construct_pspec (const Param &pdef)
   {
-    string pspec;
-    const string group = (pdef.group != "") ? pdef.group.escaped() : "NULL";
-    string pname, parg;
+    String pspec;
+    const String group = (pdef.group != "") ? pdef.group.escaped() : "NULL";
+    String pname, parg;
     switch (parser.typeOf (pdef.type))
       {
       case CHOICE:
@@ -205,14 +180,13 @@ class CodeGeneratorCoreC : public CodeGenerator {
       }
     pspec = "sfidl_pspec_" + pname;
     if (parg != "")
-      parg = string (", ") + parg;
+      parg = String (", ") + parg;
     if (pdef.args == "")
       pspec += "_default (" + group + ",\"" + pdef.name + parg + "\")";
     else
       pspec += " (" + group + ",\"" + pdef.name + "\"," + pdef.args + parg + ")";
     return pspec;
   }
-
   void
   generate_enum_type_id_prototypes ()
   {
@@ -265,14 +239,14 @@ class CodeGeneratorCoreC : public CodeGenerator {
       {
         if (parser.fromInclude (ei->name))
           continue;
-        string mname = makeMixedName (ei->name);
-        string lname = makeLowerName (ei->name);
+        String mname = makeMixedName (ei->name);
+        String lname = makeLowerName (ei->name);
         printf ("\ntypedef enum {\n");
         for (vector<ChoiceValue>::const_iterator ci = ei->contents.begin(); ci != ei->contents.end(); ci++)
           {
             /* don't export server side assigned choice values to the client */
             gint value = ci->value;
-            string ename = makeUpperName (ci->name);
+            String ename = makeUpperName (ci->name);
             printf ("  %s = %d,\n", ename.c_str(), value);
           }
         printf ("} %s;\n", mname.c_str());
@@ -286,11 +260,11 @@ class CodeGeneratorCoreC : public CodeGenerator {
       {
         if (parser.fromInclude (ei->name))
           continue;
-        string name = makeLowerName (ei->name);
-        printf ("static const GEnumValue %s_value[%d] = {\n", name.c_str(), ei->contents.size() + 1); // FIXME: i18n
+        String name = makeLowerName (ei->name);
+        printf ("static const GEnumValue %s_value[%zd] = {\n", name.c_str(), ei->contents.size() + 1); // FIXME: i18n
         for (vector<ChoiceValue>::const_iterator ci = ei->contents.begin(); ci != ei->contents.end(); ci++)
           {
-            string ename = makeUpperName (ci->name);
+            String ename = makeUpperName (ci->name);
             printf ("  { %d, \"%s\", \"%s\" },\n", ci->value, ename.c_str(), ci->label.c_str());
           }
         printf ("  { 0, NULL, NULL }\n");
@@ -317,7 +291,7 @@ class CodeGeneratorCoreC : public CodeGenerator {
       {
         if (parser.fromInclude (ei->name))
           continue;
-        string name = makeLowerName (ei->name);
+        String name = makeLowerName (ei->name);
         printf ("SfiChoiceValues\n");
         printf ("%s_get_values (void)\n", makeLowerName (ei->name).c_str());
         printf ("{\n");
@@ -336,10 +310,8 @@ class CodeGeneratorCoreC : public CodeGenerator {
         printf ("  }\n");
         printf ("  return choice_values;\n");
         printf ("}\n");
-        
         printf ("GType %s = 0;\n", make_TYPE_MACRO (ei->name));
         printf ("\n");
-        
         enumCount++;
       }
     if (enumCount)
@@ -360,7 +332,7 @@ class CodeGeneratorCoreC : public CodeGenerator {
       {
         if (parser.fromInclude (ri->name))
           continue;
-        string mname = makeMixedName (ri->name);
+        String mname = makeMixedName (ri->name);
         printf ("typedef struct _%s %s;\n", mname.c_str(), mname.c_str());
       }
   }
@@ -371,9 +343,7 @@ class CodeGeneratorCoreC : public CodeGenerator {
     for (vector<Record>::const_iterator ri = parser.getRecords().begin(); ri != parser.getRecords().end(); ri++)
       {
         if (parser.fromInclude (ri->name)) continue;
-        
-        string mname = makeMixedName (ri->name.c_str());
-        
+        String mname = makeMixedName (ri->name.c_str());
         printf ("struct _%s {\n", mname.c_str());
         for (vector<Param>::const_iterator pi = ri->contents.begin(); pi != ri->contents.end(); pi++)
           {
@@ -433,11 +403,9 @@ class CodeGeneratorCoreC : public CodeGenerator {
     for (vector<Record>::const_iterator ri = parser.getRecords().begin(); ri != parser.getRecords().end(); ri++)
       {
         if (parser.fromInclude (ri->name)) continue;
-        
-        string ret = TypeRet (ri->name);
-        string arg = TypeArg (ri->name);
-        string lname = makeLowerName (ri->name.c_str());
-        
+        String ret = TypeRet (ri->name);
+        String arg = TypeArg (ri->name);
+        String lname = makeLowerName (ri->name.c_str());
         printf ("SfiRecFields %s_get_fields (void);\n", lname.c_str());
         printf ("%s %s_new (void);\n", ret.c_str(), lname.c_str());
         printf ("%s %s_copy_shallow (%s rec);\n", ret.c_str(), lname.c_str(), arg.c_str());
@@ -455,9 +423,8 @@ class CodeGeneratorCoreC : public CodeGenerator {
       {
         if (parser.fromInclude (ri->name))
           continue;
-        string ret = TypeRet (ri->name);
+        String ret = TypeRet (ri->name);
         const gchar *type = make_fqtn (ri->name);
-
         printf ("static inline %s\n", ret.c_str());
         printf ("hack_cast (%s *cxxstruct)\n", type);
         printf ("{\n");
@@ -478,26 +445,22 @@ class CodeGeneratorCoreC : public CodeGenerator {
       {
         if (parser.fromInclude (ri->name))
           continue;
-        string ret = TypeRet (ri->name);
-        string arg = TypeArg (ri->name);
-        string lname = makeLowerName (ri->name.c_str());
-        string mname = makeMixedName (ri->name.c_str());
-
+        String ret = TypeRet (ri->name);
+        String arg = TypeArg (ri->name);
+        String lname = makeLowerName (ri->name.c_str());
+        String mname = makeMixedName (ri->name.c_str());
         const gchar *type = make_fqtn (ri->name);
-
         printf ("SfiRecFields\n");
         printf ("%s_get_fields (void)\n", lname.c_str());
         printf ("{\n");
         printf ("  return %s::get_fields ();\n", type);
         printf ("}\n");
-
         printf ("%s\n", ret.c_str());
         printf ("%s_new (void)\n", lname.c_str());
         printf ("{\n");
         printf ("  %sHandle rh (Sfi::INIT_DEFAULT); \n", type);
         printf ("  return hack_cast (rh.steal());\n");
         printf ("}\n");
-        
         printf ("%s\n", ret.c_str());
         printf ("%s_copy_shallow (%s cstruct)\n", lname.c_str(), arg.c_str());
         printf ("{\n");
@@ -505,14 +468,12 @@ class CodeGeneratorCoreC : public CodeGenerator {
         printf ("  rh.set_boxed (hack_cast (cstruct));\n");
         printf ("  return hack_cast (rh.steal());\n");
         printf ("}\n");
-        
         printf ("%s\n", ret.c_str());
         printf ("%s_from_rec (SfiRec *rec)\n", lname.c_str());
         printf ("{\n");
         printf ("  %sHandle rh = %s::from_rec (rec);\n", type, type);
         printf ("  return hack_cast (rh.steal());\n");
         printf ("}\n");
-        
         printf ("SfiRec*\n");
         printf ("%s_to_rec (%s cstruct)\n", lname.c_str(), arg.c_str());
         printf ("{\n");
@@ -520,7 +481,6 @@ class CodeGeneratorCoreC : public CodeGenerator {
         printf ("  rh.set_boxed (hack_cast (cstruct));\n");
         printf ("  return %s::to_rec (rh);\n", type);
         printf ("}\n");
-        
         printf ("void\n");
         printf ("%s_free (%s cstruct)\n", lname.c_str(), arg.c_str());
         printf ("{\n");
@@ -538,21 +498,16 @@ class CodeGeneratorCoreC : public CodeGenerator {
       {
         if (parser.fromInclude (ri->name))
           continue;
-        
-        string name = makeLowerName (ri->name);
-        
+        String name = makeLowerName (ri->name);
         printf ("static GParamSpec *%s_field[%zd];\n", name.c_str(), ri->contents.size());
         printf ("SfiRecFields %s_fields = { %zd, %s_field };\n", name.c_str(), ri->contents.size(), name.c_str());
-        
-        string mname = makeMixedName (ri->name);
-        
+        String mname = makeMixedName (ri->name);
         printf ("static void\n");
         printf ("%s_boxed2rec (const GValue *src_value, GValue *dest_value)\n", name.c_str());
         printf ("{\n");
         printf ("  gpointer boxed = g_value_get_boxed (src_value);\n");
         printf ("  sfi_value_take_rec (dest_value, boxed ? %s_to_rec (boxed) : NULL);\n", name.c_str());
         printf ("}\n");
-        
         printf ("static void\n");
         printf ("%s_rec2boxed (const GValue *src_value, GValue *dest_value)\n", name.c_str());
         printf ("{\n");
@@ -560,7 +515,6 @@ class CodeGeneratorCoreC : public CodeGenerator {
         printf ("  g_value_take_boxed (dest_value,\n");
         printf ("    rec ? %s_from_rec (rec) : NULL);\n", name.c_str());
         printf ("}\n");
-        
         printInfoStrings (name + "_info_strings", ri->infos);
         printf ("static SfiBoxedRecordInfo %s_boxed_info = {\n", name.c_str());
         printf ("  \"%s\",\n", mname.c_str());
@@ -580,7 +534,7 @@ class CodeGeneratorCoreC : public CodeGenerator {
       {
         if (parser.fromInclude (si->name))
           continue;
-        string mname = makeMixedName (si->name);
+        String mname = makeMixedName (si->name);
         printf ("typedef struct _%s %s;\n", mname.c_str(), mname.c_str());
       }
   }
@@ -591,11 +545,9 @@ class CodeGeneratorCoreC : public CodeGenerator {
     for (vector<Sequence>::const_iterator si = parser.getSequences().begin(); si != parser.getSequences().end(); si++)
       {
         if (parser.fromInclude (si->name)) continue;
-        
-        string mname = makeMixedName (si->name.c_str());
-        string array = string (TypeField (si->content.type)) + "*";
-        string elements = si->content.name;
-        
+        String mname = makeMixedName (si->name.c_str());
+        String array = String (TypeField (si->content.type)) + "*";
+        String elements = si->content.name;
         printf ("struct _%s {\n", mname.c_str());
         printf ("  guint n_%s;\n", elements.c_str ());
         printf ("  %s %s;\n", array.c_str(), elements.c_str());
@@ -653,12 +605,10 @@ class CodeGeneratorCoreC : public CodeGenerator {
     for (vector<Sequence>::const_iterator si = parser.getSequences().begin(); si != parser.getSequences().end(); si++)
       {
         if (parser.fromInclude (si->name)) continue;
-
-        string ret = TypeRet (si->name);
-        string arg = TypeArg (si->name);
-        string element = TypeArg (si->content.type);
-        string lname = makeLowerName (si->name.c_str());
-
+        String ret = TypeRet (si->name);
+        String arg = TypeArg (si->name);
+        String element = TypeArg (si->content.type);
+        String lname = makeLowerName (si->name.c_str());
         printf ("GParamSpec* %s_get_element (void);\n", lname.c_str());
         printf ("%s %s_new (void);\n", ret.c_str(), lname.c_str());
         printf ("void %s_append (%s seq, %s element);\n", lname.c_str(), arg.c_str(), element.c_str());
@@ -678,9 +628,8 @@ class CodeGeneratorCoreC : public CodeGenerator {
       {
         if (parser.fromInclude (si->name))
           continue;
-        string ret = TypeRet (si->name);
+        String ret = TypeRet (si->name);
         const gchar *type = make_fqtn (si->name);
-
         /* the cast functions take an extra unused sequence argument, to distinguish
          * two sequences A and B which both have the same CSeq type (e.g. SfiInt and SfiNote).
          */
@@ -704,27 +653,23 @@ class CodeGeneratorCoreC : public CodeGenerator {
       {
         if (parser.fromInclude (si->name))
           continue;
-        string ret = TypeRet (si->name);
-        string arg = TypeArg (si->name);
-        string element = TypeArg (si->content.type);
-        string elements = si->content.name;
-        string lname = makeLowerName (si->name.c_str());
-        
+        String ret = TypeRet (si->name);
+        String arg = TypeArg (si->name);
+        String element = TypeArg (si->content.type);
+        String elements = si->content.name;
+        String lname = makeLowerName (si->name.c_str());
         const gchar *type = make_fqtn (si->name);
-
         printf ("GParamSpec*\n");
         printf ("%s_get_element (void)\n", lname.c_str());
         printf ("{\n");
         printf ("  return %s::get_element ();\n", type);
         printf ("}\n");
-
         printf ("%s\n", ret.c_str());
         printf ("%s_new (void)\n", lname.c_str());
         printf ("{\n");
         printf ("  %s sh (0);\n", type);
         printf ("  return hack_cast (sh, sh.steal());\n");
         printf ("}\n");
-        
         printf ("void\n");
         printf ("%s_append (%s cseq, %s element)\n", lname.c_str(), arg.c_str(), element.c_str());
         printf ("{\n");
@@ -734,7 +679,6 @@ class CodeGeneratorCoreC : public CodeGenerator {
         printf ("  sh += %s;\n", cxx_handle (si->content.type, "element"));
         printf ("  sh.steal(); /* prevent cseq deletion */\n");
         printf ("}\n");
-        
         printf ("%s\n", ret.c_str());
         printf ("%s_copy_shallow (%s cseq)\n", lname.c_str(), arg.c_str());
         printf ("{\n");
@@ -742,14 +686,12 @@ class CodeGeneratorCoreC : public CodeGenerator {
         printf ("  sh.set_boxed (hack_cast (cseq));\n");
         printf ("  return hack_cast (sh, sh.steal());\n");
         printf ("}\n");
-        
         printf ("%s\n", ret.c_str());
         printf ("%s_from_seq (SfiSeq *seq)\n", lname.c_str());
         printf ("{\n");
         printf ("  %s sh = %s::from_seq (seq);\n", type, type);
         printf ("  return hack_cast (sh, sh.steal());\n");
         printf ("}\n");
-        
         printf ("SfiSeq*\n");
         printf ("%s_to_seq (%s cseq)\n", lname.c_str(), arg.c_str());
         printf ("{\n");
@@ -759,7 +701,6 @@ class CodeGeneratorCoreC : public CodeGenerator {
         printf ("  sh.steal(); /* prevent cseq deletion */\n");
         printf ("  return seq;\n");
         printf ("}\n");
-        
         printf ("void\n");
         printf ("%s_resize (%s cseq, guint n)\n", lname.c_str(), arg.c_str());
         printf ("{\n");
@@ -769,7 +710,6 @@ class CodeGeneratorCoreC : public CodeGenerator {
         printf ("  sh.resize (n);\n");
         printf ("  sh.steal(); /* prevent cseq deletion */\n");
         printf ("}\n");
-
         printf ("void\n");
         printf ("%s_free (%s cseq)\n", lname.c_str(), arg.c_str());
         printf ("{\n");
@@ -786,20 +726,15 @@ class CodeGeneratorCoreC : public CodeGenerator {
     for (vector<Sequence>::const_iterator si = parser.getSequences().begin(); si != parser.getSequences().end(); si++)
       {
         if (parser.fromInclude (si->name)) continue;
-        
-        string name = makeLowerName (si->name);
-        
+        String name = makeLowerName (si->name);
         printf ("static GParamSpec *%s_content;\n", name.c_str());
-        
-        string mname = makeMixedName (si->name);
-        
+        String mname = makeMixedName (si->name);
         printf ("static void\n");
         printf ("%s_boxed2seq (const GValue *src_value, GValue *dest_value)\n", name.c_str());
         printf ("{\n");
         printf ("  gpointer boxed = g_value_get_boxed (src_value);\n");
         printf ("  sfi_value_take_seq (dest_value, boxed ? %s_to_seq (boxed) : NULL);\n", name.c_str());
         printf ("}\n");
-        
         printf ("static void\n");
         printf ("%s_seq2boxed (const GValue *src_value, GValue *dest_value)\n", name.c_str());
         printf ("{\n");
@@ -807,7 +742,6 @@ class CodeGeneratorCoreC : public CodeGenerator {
         printf ("  g_value_take_boxed (dest_value,\n");
         printf ("    seq ? %s_from_seq (seq) : NULL);\n", name.c_str());
         printf ("}\n");
-        
         printInfoStrings (name + "_info_strings", si->infos);
         printf ("static SfiBoxedSequenceInfo %s_boxed_info = {\n", name.c_str());
         printf ("  \"%s\",\n", mname.c_str());
@@ -826,19 +760,16 @@ class CodeGeneratorCoreC : public CodeGenerator {
     printf ("\n\n/* type initialization function */\n");
     printf ("static void\n%s (void)\n", generateInitFunction.c_str());
     printf ("{\n");
-    
     /*
      * It is important to follow the declaration order of the idl file here, as for
      * instance a Param inside a record might come from a sequence, and a Param
      * inside a Sequence might come from a record - to avoid using yet-unitialized
      * Params, we follow the getTypes() 
      */
-    vector<string>::const_iterator ti;
-    
+    vector<String>::const_iterator ti;
     for(ti = parser.getTypes().begin(); ti != parser.getTypes().end(); ti++)
       {
         if (parser.fromInclude (*ti)) continue;
-        
         if (parser.isRecord (*ti) || parser.isSequence (*ti))
           {
             if (!first)
@@ -848,10 +779,8 @@ class CodeGeneratorCoreC : public CodeGenerator {
         if (parser.isRecord (*ti))
           {
             const Record& rdef = parser.findRecord (*ti);
-            
-            string name = makeLowerName (rdef.name);
+            String name = makeLowerName (rdef.name);
             int f = 0;
-            
             for (vector<Param>::const_iterator pi = rdef.contents.begin(); pi != rdef.contents.end(); pi++, f++)
               {
                 if (generateIdlLineNumbers)
@@ -862,9 +791,7 @@ class CodeGeneratorCoreC : public CodeGenerator {
         if (parser.isSequence (*ti))
           {
             const Sequence& sdef = parser.findSequence (*ti);
-            
-            string name = makeLowerName (sdef.name);
-            
+            String name = makeLowerName (sdef.name);
             if (generateIdlLineNumbers)
               printf ("#line %u \"%s\"\n", sdef.content.line, parser.fileName().c_str());
             printf ("  %s_content = %s;\n", name.c_str(), construct_pspec (sdef.content).c_str());
@@ -873,11 +800,9 @@ class CodeGeneratorCoreC : public CodeGenerator {
     for (vector<Choice>::const_iterator ei = parser.getChoices().begin(); ei != parser.getChoices().end(); ei++)
       {
         if (parser.fromInclude (ei->name)) continue;
-        
-        string gname = make_TYPE_MACRO (ei->name);
-        string name = makeLowerName(ei->name);
-        string mname = makeMixedName(ei->name);
-        
+        String gname = make_TYPE_MACRO (ei->name);
+        String name = makeLowerName(ei->name);
+        String mname = makeMixedName(ei->name);
         printf ("  %s = g_enum_register_static (\"%s\", %s_value);\n", gname.c_str(),
                 mname.c_str(), name.c_str());
         printf ("  g_value_register_transform_func (SFI_TYPE_CHOICE, %s, choice2enum);\n",
@@ -888,10 +813,8 @@ class CodeGeneratorCoreC : public CodeGenerator {
     for (vector<Record>::const_iterator ri = parser.getRecords().begin(); ri != parser.getRecords().end(); ri++)
       {
         if (parser.fromInclude (ri->name)) continue;
-        
-        string gname = make_TYPE_MACRO (ri->name);
-        string name = makeLowerName(ri->name);
-        
+        String gname = make_TYPE_MACRO (ri->name);
+        String name = makeLowerName(ri->name);
         printf ("  %s = sfi_boxed_make_record (&%s_boxed_info,\n", gname.c_str(), name.c_str());
         printf ("    (GBoxedCopyFunc) %s_copy_shallow,\n", name.c_str());
         printf ("    (GBoxedFreeFunc) %s_free);\n", name.c_str());
@@ -899,10 +822,8 @@ class CodeGeneratorCoreC : public CodeGenerator {
     for (vector<Sequence>::const_iterator si = parser.getSequences().begin(); si != parser.getSequences().end(); si++)
       {
         if (parser.fromInclude (si->name)) continue;
-        
-        string gname = make_TYPE_MACRO (si->name);
-        string name = makeLowerName(si->name);
-        
+        String gname = make_TYPE_MACRO (si->name);
+        String name = makeLowerName(si->name);
         printf ("  %s_boxed_info.element = %s_content;\n", name.c_str(), name.c_str());
         printf ("  %s = sfi_boxed_make_sequence (&%s_boxed_info,\n", gname.c_str(), name.c_str());
         printf ("    (GBoxedCopyFunc) %s_copy_shallow,\n", name.c_str());
@@ -910,20 +831,17 @@ class CodeGeneratorCoreC : public CodeGenerator {
       }
     printf ("}\n");
   }
-  
 public:
   CodeGeneratorCoreC (const Parser& parser) :
     CodeGenerator (parser)
   {
   }
-
   bool
   run ()
   {
     printf ("\n/*-------- begin %s generated code --------*/\n\n\n", options.sfidlName.c_str());
     if (generateSource)
       printf ("#include <string.h>\n");
-    
     if (generateHeader)
       {
         generate_enum_definitions ();
@@ -943,7 +861,6 @@ public:
         generate_sequence_type_macros ();
         printf ("\n#endif\n");
       }
-
     if (generateSource)
       {
         // generate_enum_value_array ();
@@ -968,23 +885,18 @@ public:
             printf ("}\n");
           }
       }
-
     printf ("\n/*-------- end %s generated code --------*/\n\n\n", options.sfidlName.c_str());
     return true;
   }
 };
-
 class CoreCFactory : public Factory {
 public:
-  string option() const	      { return "--core-c"; }
-  string description() const  { return "generate core C language binding"; }
-  
+  String option() const	      { return "--core-c"; }
+  String description() const  { return "generate core C language binding"; }
   CodeGenerator *create (const Parser& parser) const
   {
     return new CodeGeneratorCoreC (parser);
   }
 } core_c_factory;
-
 } // anon
-
 /* vim:set ts=8 sts=2 sw=2: */
